#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2020/7/17 14:17
Desc: 新浪财经-商品期权
https://stock.finance.sina.com.cn/futures/view/optionsDP.php
"""
from typing import Dict, List

from mssdk.utils import demjson
import pandas as pd
import requests
from bs4 import BeautifulSoup


def option_sina_commodity_dict(symbol="玉米期权") -> Dict[str, List[str]]:
    """
    当前可以查询的期权品种的合约日期
    https://stock.finance.sina.com.cn/futures/view/optionsDP.php
    :param symbol: choice of {"豆粕期权", "玉米期权", "铁矿石期权", "棉花期权", "白糖期权", "PTA期权", "甲醇期权", "橡胶期权", "沪铜期权", "黄金期权", "菜籽粕期权", "液化石油气期权", "动力煤期权"}
    :type symbol: str
    :return: e.g., {'黄金期权': ['au2012', 'au2008', 'au2010', 'au2104', 'au2102', 'au2106', 'au2108']}
    :rtype: dict
    """
    url = "https://stock.finance.sina.com.cn/futures/view/optionsDP.php/pg_o/dce"
    r = requests.get(url)
    soup = BeautifulSoup(r.text, "lxml")
    url_list = [item.find("a")["href"] for item in soup.find_all("li", attrs={"class": "active"}) if item.find("a") is not None]
    commodity_list = [item.find("a").text for item in soup.find_all("li", attrs={"class": "active"}) if item.find("a") is not None]
    comm_list_dict = {key: value for key, value in zip(commodity_list, url_list)}
    url = "https://stock.finance.sina.com.cn" + comm_list_dict[symbol]
    r = requests.get(url)
    soup = BeautifulSoup(r.text, "lxml")
    symbol = soup.find(attrs={"id": "option_symbol"}).find(attrs={"class": "selected"}).text
    contract = [
        item.text for item in soup.find(attrs={"id": "option_suffix"}).find_all("li")
    ]
    return {symbol: contract}


def option_sina_commodity_contract_list(symbol="黄金期权", contract="au2012"):
    """
    当前所有期权合约, 包括看涨期权合约和看跌期权合约
    https://stock.finance.sina.com.cn/futures/view/optionsDP.php
    :param symbol: choice of {"豆粕期权", "玉米期权", "铁矿石期权", "棉花期权", "白糖期权", "PTA期权", "甲醇期权", "橡胶期权", "沪铜期权", "黄金期权", "菜籽粕期权", "液化石油气期权"}
    :type symbol: str
    :param contract: e.g., 'au2012'
    :type contract: str
    :return: 合约实时行情
    :rtype: pandas.DataFrame
    """
    url = "https://stock.finance.sina.com.cn/futures/view/optionsDP.php/pg_o/dce"
    r = requests.get(url)
    soup = BeautifulSoup(r.text, "lxml")
    url_list = [item.find("a")["href"] for item in soup.find_all("li", attrs={"class": "active"}) if item.find("a") is not None]
    commodity_list = [item.find("a").text for item in soup.find_all("li", attrs={"class": "active"}) if item.find("a") is not None]
    comm_list_dict = {key: value for key, value in zip(commodity_list, url_list)}
    url = "https://stock.finance.sina.com.cn/futures/api/openapi.php/OptionService.getOptionData"
    params = {
        "type": "futures",
        "product": comm_list_dict[symbol].split("/")[-2],
        "exchange": comm_list_dict[symbol].split("/")[-1],
        "pinzhong": contract,
    }
    r = requests.get(url, params=params)
    data_json = r.json()
    up_df = pd.DataFrame(data_json["result"]["data"]["up"])
    down_df = pd.DataFrame(data_json["result"]["data"]["down"])
    temp_df = pd.concat([up_df, down_df], axis=1)
    temp_df.columns = ["买量",
                       "买价",
                       "最新价",
                       "卖价",
                       "卖量",
                       "持仓量",
                       "涨跌",
                       "行权价",
                       "看涨期权合约",
                       "买量",
                       "买价",
                       "最新价",
                       "卖价",
                       "卖量",
                       "持仓量",
                       "涨跌",
                       "看跌期权合约",
                       ]
    return temp_df


def option_sina_commodity_hist(contract="au2012C392"):
    """
    合约历史行情-日频
    https://stock.finance.sina.com.cn/futures/view/optionsDP.php
    :param contract: return of option_sina_option_commodity_contract_list(symbol="黄金期权", contract="au2012"), 看涨期权合约 filed
    :type contract: str
    :return: 合约历史行情-日频
    :rtype: pandas.DataFrame
    """
    url = "https://stock.finance.sina.com.cn/futures/api/jsonp.php/var%20_m2009C30002020_7_17=/FutureOptionAllService.getOptionDayline"
    params = {
        "symbol": contract
    }
    r = requests.get(url, params=params)
    data_text = r.text
    data_json = demjson.decode(data_text[data_text.find("["):-2])
    temp_df = pd.DataFrame(data_json)
    temp_df.columns = ["open", "high", "low", "close", "volume", "date"]
    temp_df = temp_df[["date", "open", "high", "low", "close", "volume"]]
    return temp_df


if __name__ == '__main__':
    option_sina_commodity_dict(symbol="动力煤期权")
    option_sina_contract_list_df = option_sina_commodity_contract_list(symbol="动力煤期权", contract="zc2103")
    print(option_sina_contract_list_df["看涨期权合约"])
    option_sina_hist_df = option_sina_commodity_hist(contract="zc2103C560")
    print(option_sina_hist_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2021/2/7 15:35
Desc: 股票基本面数据
新浪财经-财务报表-财务摘要
https://vip.stock.finance.sina.com.cn/corp/go.php/vFD_FinanceSummary/stockid/600004.phtml
新浪财经-财务分析-财务指标
https://money.finance.sina.com.cn/corp/go.php/vFD_FinancialGuideLine/stockid/600004/displaytype/4.phtml
新浪财经-发行与分配
http://money.finance.sina.com.cn/corp/go.php/vISSUE_ShareBonus/stockid/600004.phtml
"""
import pandas as pd
import requests
from bs4 import BeautifulSoup
from tqdm import tqdm

from io import BytesIO


def stock_financial_report_sina(stock: str = "600004", symbol: str = "现金流量表") -> pd.DataFrame:
    """
    新浪财经-财务报表-三大报表
    https://vip.stock.finance.sina.com.cn/corp/go.php/vFD_BalanceSheet/stockid/600004/ctrl/part/displaytype/4.phtml
    :param stock: 股票代码
    :type stock: str
    :param symbol: choice of {"资产负债表", "利润表", "现金流量表"}
    :type symbol:
    :return: 新浪财经-财务报表-三大报表
    :rtype: pandas.DataFrame
    """
    if symbol == "资产负债表":
        url = f"http://money.finance.sina.com.cn/corp/go.php/vDOWN_BalanceSheet/displaytype/4/stockid/{stock}/ctrl/all.phtml"  # 资产负债表
    elif symbol == "利润表":
        url = f"http://money.finance.sina.com.cn/corp/go.php/vDOWN_ProfitStatement/displaytype/4/stockid/{stock}/ctrl/all.phtml"  # 利润表
    elif symbol == "现金流量表":
        url = f"http://money.finance.sina.com.cn/corp/go.php/vDOWN_CashFlow/displaytype/4/stockid/{stock}/ctrl/all.phtml"  # 现金流量表
    r = requests.get(url)
    temp_df = pd.read_table(BytesIO(r.content), encoding="gb2312", header=None).iloc[:, :-2]
    temp_df = temp_df.T
    temp_df.columns = temp_df.iloc[0, :]
    temp_df = temp_df.iloc[1:, :]
    temp_df.index.name = None
    temp_df.columns.name = None
    return temp_df


def stock_financial_abstract(stock: str = "600004") -> pd.DataFrame:
    """
    新浪财经-财务报表-财务摘要
    https://vip.stock.finance.sina.com.cn/corp/go.php/vFD_FinanceSummary/stockid/600004.phtml
    :param stock: 股票代码
    :type stock: str
    :return: 新浪财经-财务报表-财务摘要
    :rtype: pandas.DataFrame
    """
    url = f"https://vip.stock.finance.sina.com.cn/corp/go.php/vFD_FinanceSummary/stockid/{stock}.phtml"
    r = requests.get(url)
    temp_df = pd.read_html(r.text)[13].iloc[:, :2]
    big_df = pd.DataFrame()
    for i in range(0, len(temp_df), 12):
        truncated_df = temp_df.iloc[i: i + 11, 1]
        big_df = pd.concat([big_df, truncated_df.reset_index(drop=True)], axis=1, ignore_index=True)
    data_df = big_df.T
    data_df.columns = temp_df.iloc[:11, 0].tolist()
    return data_df


def stock_financial_analysis_indicator(stock: str = "600004") -> pd.DataFrame:
    """
    新浪财经-财务分析-财务指标
    https://money.finance.sina.com.cn/corp/go.php/vFD_FinancialGuideLine/stockid/600004/ctrl/2019/displaytype/4.phtml
    :param stock: 股票代码
    :type stock: str
    :return: 新浪财经-财务分析-财务指标
    :rtype: pandas.DataFrame
    """
    url = f"https://money.finance.sina.com.cn/corp/go.php/vFD_FinancialGuideLine/stockid/{stock}/ctrl/2020/displaytype/4.phtml"
    r = requests.get(url)
    soup = BeautifulSoup(r.text, "lxml")
    year_context = soup.find(attrs={"id": "con02-1"}).find("table").find_all("a")
    year_list = [item.text for item in year_context]
    out_df = pd.DataFrame()
    for year_item in tqdm(year_list, leave=False):
        url = f"https://money.finance.sina.com.cn/corp/go.php/vFD_FinancialGuideLine/stockid/{stock}/ctrl/{year_item}/displaytype/4.phtml"
        r = requests.get(url)
        temp_df = pd.read_html(r.text)[12].iloc[:, :-1]
        temp_df.columns = temp_df.iloc[0, :]
        temp_df = temp_df.iloc[1:, :]
        big_df = pd.DataFrame()
        indicator_list = ["每股指标", "盈利能力", "成长能力", "营运能力", "偿债及资本结构", "现金流量", "其他指标"]
        for i in range(len(indicator_list)):
            if i == 6:
                inner_df = temp_df[temp_df.loc[temp_df.iloc[:, 0].str.find(indicator_list[i]) == 0, :].index[0]:].T
            else:
                inner_df = temp_df[temp_df.loc[temp_df.iloc[:, 0].str.find(indicator_list[i]) == 0, :].index[0]: temp_df.loc[temp_df.iloc[:, 0].str.find(indicator_list[i+1]) == 0, :].index[0]-1].T
            inner_df = inner_df.reset_index(drop=True)
            big_df = pd.concat([big_df, inner_df], axis=1)
        big_df.columns = big_df.iloc[0, :].tolist()
        big_df = big_df.iloc[1:, :]
        big_df.index = temp_df.columns.tolist()[1:]
        out_df = out_df.append(big_df)
    out_df.dropna(inplace=True)
    return out_df


def stock_history_dividend() -> pd.DataFrame:
    """
    新浪财经-发行与分配-历史分红
    http://vip.stock.finance.sina.com.cn/q/go.php/vInvestConsult/kind/lsfh/index.phtml?p=1&num=5000
    :return: 所有股票的历史分红数据
    :rtype: pandas.DataFrame
    """
    url = "http://vip.stock.finance.sina.com.cn/q/go.php/vInvestConsult/kind/lsfh/index.phtml"
    params = {
        "p": "1",
        "num": "5000"
    }
    r = requests.get(url, params=params)
    temp_df = pd.read_html(r.text)[0]
    temp_df["代码"] = temp_df["代码"].astype(str)
    temp_df["代码"] = temp_df["代码"].str.zfill(6)
    return temp_df


def stock_history_dividend_detail(indicator: str = "分红", stock: str = "000541", date: str = "1994-12-24") -> pd.DataFrame:
    """
    新浪财经-发行与分配-分红配股详情
    https://vip.stock.finance.sina.com.cn/corp/go.php/vISSUE_ShareBonus/stockid/300670.phtml
    :param indicator: choice of {"分红", "配股"}
    :type indicator: str
    :param stock: 股票代码
    :type stock: str
    :param date: 分红配股的具体日期, e.g., "1994-12-24"
    :type date: str
    :return: 指定 indicator, stock, date 的数据
    :rtype: pandas.DataFrame
    """
    if indicator == "分红":
        url = f"http://vip.stock.finance.sina.com.cn/corp/go.php/vISSUE_ShareBonus/stockid/{stock}.phtml"
        r = requests.get(url)
        temp_df = pd.read_html(r.text)[12]
        temp_df.columns = [item[2] for item in temp_df.columns.tolist()]
        if date:
            url = "https://vip.stock.finance.sina.com.cn/corp/view/vISSUE_ShareBonusDetail.php"
            params = {
                "stockid": stock,
                "type": "1",
                "end_date": date,
            }
            r = requests.get(url, params=params)
            temp_df = pd.read_html(r.text)[12]
            temp_df.columns = ["item", "value"]
            return temp_df
        else:
            return temp_df
    else:
        url = f"http://vip.stock.finance.sina.com.cn/corp/go.php/vISSUE_ShareBonus/stockid/{stock}.phtml"
        r = requests.get(url)
        temp_df = pd.read_html(r.text)[13]
        temp_df.columns = [item[1] for item in temp_df.columns.tolist()]
        if date:
            url = "https://vip.stock.finance.sina.com.cn/corp/view/vISSUE_ShareBonusDetail.php"
            params = {
                "stockid": stock,
                "type": "2",
                "end_date": date,
            }
            r = requests.get(url, params=params)
            temp_df = pd.read_html(r.text)[12]
            temp_df.columns = ["item", "value"]
            return temp_df
        else:
            return temp_df


def stock_ipo_info(stock: str = "600004") -> pd.DataFrame:
    """
    新浪财经-发行与分配-新股发行
    https://vip.stock.finance.sina.com.cn/corp/go.php/vISSUE_NewStock/stockid/600004.phtml
    :param stock: 股票代码
    :type stock: str
    :return: 返回新股发行详情
    :rtype: pandas.DataFrame
    """
    url = f"https://vip.stock.finance.sina.com.cn/corp/go.php/vISSUE_NewStock/stockid/{stock}.phtml"
    r = requests.get(url)
    temp_df = pd.read_html(r.text)[12]
    temp_df.columns = ["item", "value"]
    return temp_df


def stock_add_stock(stock: str = "688166") -> pd.DataFrame:
    """
    新浪财经-发行与分配-增发
    https://vip.stock.finance.sina.com.cn/corp/go.php/vISSUE_AddStock/stockid/600004.phtml
    :param stock: 股票代码
    :type stock: str
    :return: 返回增发详情
    :rtype: pandas.DataFrame
    """
    url = f"https://vip.stock.finance.sina.com.cn/corp/go.php/vISSUE_AddStock/stockid/{stock}.phtml"
    r = requests.get(url)
    temp_df = pd.read_html(r.text)[12]
    if temp_df.at[0, 0] == '对不起，暂时没有相关增发记录':
        return f"股票 {stock} 无增发记录"
    big_df = pd.DataFrame()
    for i in range(int(len(temp_df.at[0, 1]) / 10)):
        temp_df = pd.read_html(r.text)[13+i].iloc[:, 1]
        big_df[temp_df.name.split(" ")[1].split("：")[1][:10]] = temp_df
    big_df = big_df.T
    big_df.columns = ["发行方式", "发行价格", "实际公司募集资金总额", "发行费用总额", "实际发行数量"]
    return big_df


def stock_restricted_shares(stock: str = "600000") -> pd.DataFrame:
    """
    新浪财经-发行分配-限售解禁
    https://vip.stock.finance.sina.com.cn/q/go.php/vInvestConsult/kind/xsjj/index.phtml?symbol=sh600000
    :param stock: 股票代码
    :type stock: str
    :return: 返回限售解禁数据
    :rtype: pandas.DataFrame
    """
    url = f"https://vip.stock.finance.sina.com.cn/q/go.php/vInvestConsult/kind/xsjj/index.phtml?symbol={stock}"
    r = requests.get(url)
    temp_df = pd.read_html(r.text)[0]
    return temp_df


def stock_circulate_stock_holder(stock: str = "600000") -> pd.DataFrame:
    """
    新浪财经-股东股本-流通股东
    P.S. 特定股票特定时间只有前 5 个; e.g., 000002
    https://vip.stock.finance.sina.com.cn/corp/go.php/vCI_CirculateStockHolder/stockid/600000.phtml
    :param stock: 股票代码
    :type stock: str
    :return: 新浪财经-股东股本-流通股东
    :rtype: pandas.DataFrame
    """
    url = f"https://vip.stock.finance.sina.com.cn/corp/go.php/vCI_CirculateStockHolder/stockid/{stock}.phtml"
    r = requests.get(url)
    temp_df = pd.read_html(r.text)[13].iloc[:, :5]
    temp_df.columns = [*range(5)]
    big_df = pd.DataFrame()
    need_range = temp_df[temp_df.iloc[:, 0].str.find("截止日期") == 0].index.tolist() + [len(temp_df)]
    for i in range(len(need_range)-1):
        truncated_df = temp_df.iloc[need_range[i]: need_range[i + 1], :]
        truncated_df = truncated_df.dropna(how="all")
        temp_truncated = truncated_df.iloc[2:, :]
        temp_truncated.reset_index(inplace=True, drop=True)
        concat_df = pd.concat([temp_truncated, truncated_df.iloc[0, :], truncated_df.iloc[1, :]], axis=1)
        concat_df.columns = concat_df.iloc[0, :]
        concat_df = concat_df.iloc[1:, :]
        concat_df["截止日期"] = concat_df["截止日期"].fillna(method="ffill")
        concat_df["公告日期"] = concat_df["公告日期"].fillna(method="ffill")
        big_df = pd.concat([big_df, concat_df], axis=0, ignore_index=True)
    big_df = big_df[["截止日期", "公告日期", "编号", "股东名称", "持股数量(股)", "占流通股比例(%)", "股本性质"]]
    big_df.reset_index(inplace=True, drop=True)
    return big_df


def stock_fund_stock_holder(stock: str = "600004") -> pd.DataFrame:
    """
    新浪财经-股本股东-基金持股
    https://vip.stock.finance.sina.com.cn/corp/go.php/vCI_FundStockHolder/stockid/600004.phtml
    :param stock: 股票代码
    :type stock: str
    :return: 新浪财经-股本股东-基金持股
    :rtype: pandas.DataFrame
    """
    url = f"https://vip.stock.finance.sina.com.cn/corp/go.php/vCI_FundStockHolder/stockid/{stock}.phtml"
    r = requests.get(url)
    temp_df = pd.read_html(r.text)[13].iloc[:, :5]
    temp_df.columns = [*range(5)]
    big_df = pd.DataFrame()
    need_range = temp_df[temp_df.iloc[:, 0].str.find("截止日期") == 0].index.tolist() + [len(temp_df)]
    for i in range(len(need_range)-1):
        truncated_df = temp_df.iloc[need_range[i]: need_range[i + 1], :]
        truncated_df = truncated_df.dropna(how="all")
        temp_truncated = truncated_df.iloc[2:, :]
        temp_truncated.reset_index(inplace=True, drop=True)
        concat_df = pd.concat([temp_truncated, truncated_df.iloc[0, 1:]], axis=1)
        concat_df.columns = truncated_df.iloc[1, :].tolist() + ["截止日期"]
        concat_df["截止日期"] = concat_df["截止日期"].fillna(method="ffill")
        concat_df["截止日期"] = concat_df["截止日期"].fillna(method="bfill")
        big_df = pd.concat([big_df, concat_df], axis=0, ignore_index=True)
    big_df.dropna(inplace=True)
    big_df.reset_index(inplace=True, drop=True)
    return big_df


def stock_main_stock_holder(stock: str = "600004") -> pd.DataFrame:
    """
    新浪财经-股本股东-主要股东
    P.S. 特定股票特定时间只有前 5 个; e.g., 000002
    https://vip.stock.finance.sina.com.cn/corp/go.php/vCI_StockHolder/stockid/600004.phtml
    :param stock: 股票代码
    :type stock: str
    :return: 新浪财经-股本股东-主要股东
    :rtype: pandas.DataFrame
    """
    url = f"https://vip.stock.finance.sina.com.cn/corp/go.php/vCI_StockHolder/stockid/{stock}.phtml"
    r = requests.get(url)
    temp_df = pd.read_html(r.text)[13].iloc[:, :5]
    temp_df.columns = [*range(5)]
    big_df = pd.DataFrame()
    need_range = temp_df[temp_df.iloc[:, 0].str.find("截至日期") == 0].index.tolist() + [len(temp_df)]
    for i in range(len(need_range)-1):
        truncated_df = temp_df.iloc[need_range[i]: need_range[i + 1], :]
        truncated_df = truncated_df.dropna(how="all")
        temp_truncated = truncated_df.iloc[5:, :]
        temp_truncated.reset_index(inplace=True, drop=True)
        concat_df = pd.concat([temp_truncated, truncated_df.iloc[0, :], truncated_df.iloc[1, :], truncated_df.iloc[2, :],
                               truncated_df.iloc[3, :], truncated_df.iloc[4, :]], axis=1)
        concat_df.columns = concat_df.iloc[0, :]
        concat_df = concat_df.iloc[1:, :]
        concat_df["截至日期"] = concat_df["截至日期"].fillna(method="ffill")
        concat_df["公告日期"] = concat_df["公告日期"].fillna(method="ffill")
        concat_df["股东总数"] = concat_df["股东总数"].fillna(method="ffill")
        concat_df["平均持股数"] = concat_df["平均持股数"].fillna(method="ffill")
        concat_df["股东总数"] = concat_df["股东总数"].str.strip("查看变化趋势")
        concat_df["平均持股数"] = concat_df["平均持股数"].str.strip("(按总股本计算) 查看变化趋势")
        big_df = pd.concat([big_df, concat_df], axis=0, ignore_index=True)
    big_df.dropna(inplace=True, how="all")
    big_df.reset_index(inplace=True, drop=True)
    return big_df


if __name__ == '__main__':
    stock_financial_report_sina_df = stock_financial_report_sina(stock="600009", symbol="现金流量表")
    print(stock_financial_report_sina_df)

    stock_financial_report_sina_df = stock_financial_report_sina(stock="600004", symbol="资产负债表")
    print(stock_financial_report_sina_df)

    stock_financial_abstract_df = stock_financial_abstract(stock="600004")
    print(stock_financial_abstract_df)

    stock_financial_analysis_indicator_df = stock_financial_analysis_indicator(stock="002230")
    print(stock_financial_analysis_indicator_df)

    stock_history_dividend_df = stock_history_dividend()
    print(stock_history_dividend_df)

    stock_history_dividend_detail_df = stock_history_dividend_detail(indicator="分红", stock="600012", date="")
    print(stock_history_dividend_detail_df)

    stock_history_dividend_detail_df = stock_history_dividend_detail(indicator="分红", stock="600012", date="2019-07-08")
    print(stock_history_dividend_detail_df)

    stock_history_dividend_detail_df = stock_history_dividend_detail(indicator="配股", stock="000002", date="1999-12-22")
    print(stock_history_dividend_detail_df)

    stock_ipo_info_df = stock_ipo_info(stock="600004")
    print(stock_ipo_info_df)

    stock_add_stock_df = stock_add_stock(stock="600004")
    print(stock_add_stock_df)

    stock_restricted_shares_df = stock_restricted_shares(stock="600000")
    print(stock_restricted_shares_df)

    stock_circulate_stock_holder_df = stock_circulate_stock_holder(stock="600000")
    print(stock_circulate_stock_holder_df)

    stock_fund_stock_holder_df = stock_fund_stock_holder(stock="601318")
    print(stock_fund_stock_holder_df)

    stock_main_stock_holder_df = stock_main_stock_holder(stock="600000")
    print(stock_main_stock_holder_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2021/5/9 16:16
Desc: 浙江省排污权交易指数
https://zs.zjpwq.net/
"""
import requests
import pandas as pd


def index_eri() -> pd.DataFrame:
    """
    浙江省排污权交易指数
    https://zs.zjpwq.net
    :return: 浙江省排污权交易指数
    :rtype: pandas.DataFrame
    """
    url = "https://zs.zjpwq.net/zhe-jiang-pwq-webapi/indexData"
    params = {
        "indexId": "1",
        "areaCode": "330000",
        "cycle": "MONTH",
        "structCode": "01",
    }
    r = requests.get(url, params=params)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["data"])
    del temp_df["id"]
    del temp_df["indexId"]
    del temp_df["stageId"]
    del temp_df["structCode"]
    del temp_df["areaCode"]
    del temp_df["rawValue"]
    temp_df.columns = [
        "value",
        "date",
    ]
    temp_df = temp_df[
        [
            "date",
            "value",
        ]
    ]
    big_df = temp_df
    url = "https://zs.zjpwq.net/zhe-jiang-pwq-webapi/rawValueStatistics"
    params = {
        "orderBy": "-date",
        "pageSize": "1000",
        "quotaType": "0",
        "index": "TOTAL_QUANTITY",
        "areaCode": "330000",
    }
    r = requests.get(url, params=params)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["data"])
    del temp_df["id"]
    del temp_df["quotaType"]
    del temp_df["index"]
    temp_df.columns = [
        "date",
        "value",
        "update",
    ]
    big_df = big_df.merge(temp_df, on="date")
    big_df.columns = [
        "日期",
        "交易指数",
        "成交量",
        "更新时间",
    ]
    return big_df


if __name__ == "__main__":
    index_eri_df = index_eri()
    print(index_eri_df)



#!/usr/bin/env python# -*- coding:utf-8 -*-

"""
Date: 2021/7/15 18:03
Desc: 慈善中国
http://cishan.chinanpo.gov.cn/platform/login.html
# 慈善中国-慈善组织查询
http://cishan.chinanpo.gov.cn/biz/ma/csmh/a/csmhaindex.html
# 慈善中国-慈善信托查询
http://cishan.chinanpo.gov.cn/biz/ma/csmh/e/csmheindex.html
# 慈善中国-募捐方案备案
http://cishan.chinanpo.gov.cn/biz/ma/csmh/c/csmhcindex.html
# 慈善中国-慈善项目进展
http://cishan.chinanpo.gov.cn/biz/ma/csmh/b/csmhbindex.html
# 慈善中国-慈善组织年报
http://cishan.chinanpo.gov.cn/biz/ma/csmh/d/csmhdindex.html
# 慈善中国-募捐信息平台
http://cishan.chinanpo.gov.cn/biz/ma/csmh/h/csmhhindex.html

# TODO 移除
"""
import re
from typing import Tuple

import pandas as pd
import requests
from bs4 import BeautifulSoup
from tqdm import tqdm


# 慈善中国-慈善组织查询
def _get_page_num_charity_china_organization() -> int:
    """
    慈善中国-慈善组织查询-总页数
    :return: 总页数
    :rtype: int
    """
    url = "https://cszg.mca.gov.cn/biz/ma/csmh/a/csmhaDoSort.html"
    payload_params = {
        "aaee0102_03": "",
        "field": "aaex0131",
        "sort": "desc",
        "flag": "0",
    }
    payload_data = {"pageNo": "1"}
    r = requests.post(url, params=payload_params, data=payload_data)
    soup = BeautifulSoup(r.text, "lxml")
    page_text = soup.find(
        "font", attrs={"style": "margin-left: 10px; color: #000000; font-weight: bold;"}
    ).text.split("/")[1]
    page_num = re.findall(re.compile(r"\d+"), page_text)[0]
    return int(page_num)


def charity_china_organization() -> pd.DataFrame:
    """
    慈善中国-慈善组织查询
    https://cszg.mca.gov.cn/biz/ma/csmh/a/csmhaindex.html
    :return: 慈善中国-慈善组织查询
    :rtype: pandas.DataFrame
    """
    page_num = _get_page_num_charity_china_organization()
    url = "https://cszg.mca.gov.cn/biz/ma/csmh/a/csmhaDoSort.html"
    payload_params = {
        "aaee0102_03": "",
        "field": "aaex0131",
        "sort": "desc",
        "flag": "0",
    }
    outer_df = pd.DataFrame()
    for page in tqdm(range(1, page_num+1), leave=False):
        payload_data = {"pageNo": str(page)}
        r = requests.post(url, params=payload_params, data=payload_data)
        inner_df = pd.read_html(r.text)[0]
        outer_df = outer_df.append(inner_df, ignore_index=True)
    return outer_df


# 慈善中国-慈善信托查询
def _get_page_num_charity_china_trust() -> int:
    """
    慈善中国-慈善信托查询-总页数
    :return: 总页数
    :rtype: int
    """
    url = "https://cszg.mca.gov.cn/biz/ma/csmh/e/csmhedoSort.html"
    payload_params = {
        "aafx0103": "",
        "field": "aafx0104",
        "sort": "desc",
    }
    payload_data = {"pageNo": "1"}
    r = requests.post(url, params=payload_params, data=payload_data)
    soup = BeautifulSoup(r.text, "lxml")
    page_text = soup.find(
        "font", attrs={"style": "margin-left: 10px; color: #000000; font-weight: bold;"}
    ).text.split("/")[1]
    page_num = re.findall(re.compile(r"\d+"), page_text)[0]
    return int(page_num)


def charity_china_trust() -> pd.DataFrame:
    """
    慈善中国-慈善信托查询
    https://cszg.mca.gov.cn/biz/ma/csmh/e/csmheindex.html
    :return: 慈善中国-慈善信托查询
    :rtype: pandas.DataFrame
    """
    page_num = _get_page_num_charity_china_trust()
    url = "https://cszg.mca.gov.cn/biz/ma/csmh/e/csmhedoSort.html"
    payload_params = {
        "aafx0103": "",
        "field": "aafx0104",
        "sort": "desc",
    }
    outer_df = pd.DataFrame()
    for page in tqdm(range(1, page_num+1), leave=False):
        payload_data = {"pageNo": str(page)}
        r = requests.post(url, params=payload_params, data=payload_data)
        inner_df = pd.read_html(r.text)[0]
        outer_df = outer_df.append(inner_df, ignore_index=True)
    return outer_df


# 慈善中国-募捐方案备案
def _get_page_num_charity_china_plan() -> int:
    """
    慈善中国-募捐方案备案-总页数
    :return: 总页数
    :rtype: int
    """
    url = "https://cszg.mca.gov.cn/biz/ma/csmh/c/csmhcquerylist.html"
    payload_params = {
        "aaex9102_03": "",
        "aaex8104": "1",
    }
    payload_data = {"pageNo": "1"}
    r = requests.post(url, params=payload_params, data=payload_data)
    soup = BeautifulSoup(r.text, "lxml")
    page_text = soup.find(
        "font", attrs={"style": "margin-left: 10px; color: #000000; font-weight: bold;"}
    ).text.split("/")[1]
    page_num = re.findall(re.compile(r"\d+"), page_text.replace(",", ""))[0]
    return int(page_num)


def _get_charity_china_plan_detail(url: str = "") -> Tuple:
    """
    获取页面的详情, 需要进入二级页面访问获取, 需要增加字段可以在此函数中进行
    https://cszg.mca.gov.cn/biz/ma/csmh/c/csmhcdetail.html?id=ff8080816390694d0163f31aab60188e
    :param url: charity_china_plan 二级页面的网址
    :type url: str
    :return: 名词和备案号
    :rtype: tuple
    """
    r = requests.get(url)
    soup = BeautifulSoup(r.text, "lxml")
    title = soup.find("div", attrs={"class": "gkmj-title"}).text
    number = soup.find("div", attrs={"class": "gkmj-number"}).text
    return title, number


def charity_china_plan() -> pd.DataFrame:
    """
    慈善中国-募捐方案备案
    https://cszg.mca.gov.cn/biz/ma/csmh/c/csmhcindex.html
    :return: 慈善中国-募捐方案备案
    :rtype: pandas.DataFrame
    """
    page_num = _get_page_num_charity_china_plan()
    url = "https://cszg.mca.gov.cn/biz/ma/csmh/c/csmhcquerylist.html"
    payload_params = {
        "aaex9102_03": "",
        "aaex8104": "1",
    }
    outer_df = pd.DataFrame()
    for page in tqdm(range(1, page_num+1)):
        payload_data = {"pageNo": str(page)}
        r = requests.post(url, params=payload_params, data=payload_data)
        soup = BeautifulSoup(r.text, "lxml")
        org = [
            item.text.split("：")[1]
            for item in soup.find_all("div", attrs={"class": "gkmj-list-team"})
        ]
        status = [
            item.text.split("：")[1]
            for item in soup.find_all("div", attrs={"class": "gkmj-amount"})
        ]
        temp_list = [
            _get_charity_china_plan_detail(
                "https://cszg.mca.gov.cn" + item["href"]
            )
            for item in soup.find_all("a")
        ]
        title = [item[0] for item in temp_list]
        num = [item[1] for item in temp_list]
        inner_df = pd.DataFrame([org, status, title, num]).T
        outer_df = outer_df.append(inner_df, ignore_index=True)
    outer_df.columns = ["组织", "状态", "名称", "备案号"]
    return outer_df


# 慈善中国-慈善项目进展
def _get_page_num_charity_china_progress() -> int:
    """
    慈善中国-慈善项目进展-总页数
    :return: 总页数
    :rtype: int
    """
    url = "https://cszg.mca.gov.cn/biz/ma/csmh/b/csmhbquerylist.html"
    payload_params = {
        "aaex8102_03": "",
        "aaex8104": "1",
    }
    payload_data = {"pageNo": "1"}
    r = requests.post(url, params=payload_params, data=payload_data)
    soup = BeautifulSoup(r.text, "lxml")
    page_text = soup.find(
        "font", attrs={"style": "margin-left: 10px; color: #000000; font-weight: bold;"}
    ).text.split("/")[1]
    page_num = re.findall(re.compile(r"\d+"), page_text.replace(",", ""))[0]
    return int(page_num)


def _get_charity_china_progress_detail(url: str = "") -> Tuple[str]:
    """
    https://cszg.mca.gov.cn/biz/ma/csmh/b/csmhbdetail.html?id=ff80808170367b4c01703a5a9158053e
    :param url:
    :type url:
    :return:
    :rtype:
    """
    # url = "https://cszg.mca.gov.cn/biz/ma/csmh/b/csmhbdetail.html?id=ff80808170367b4c01703a5a9158053e"
    r = requests.get(url)
    soup = BeautifulSoup(r.text, "lxml")
    title = soup.find("div", attrs={"class": "csxm-title"}).text
    number = soup.find("div", attrs={"class": "csxm-number"}).text
    ori_org = soup.find("div", attrs={"class": "csxm-orgnize"}).text.split("】")[1]
    status = soup.find("div", attrs={"class": "csxm-comp"}).text.split("】")[1]
    return title, number, ori_org, status


def charity_china_progress() -> pd.DataFrame:
    """
    慈善中国-慈善项目进展
    https://cszg.mca.gov.cn/biz/ma/csmh/b/csmhbindex.html
    :return: 慈善中国-慈善项目进展
    :rtype: pandas.DataFrame
    """
    page_num = _get_page_num_charity_china_progress()
    url = "https://cszg.mca.gov.cn/biz/ma/csmh/b/csmhbquerylist.html"
    payload_params = {
        "aaex8102_03": "",
        "aaex8104": "1",
    }
    outer_df = pd.DataFrame()
    for page in tqdm(range(1, page_num)):
        payload_data = {"pageNo": str(page)}
        r = requests.post(url, params=payload_params, data=payload_data)
        soup = BeautifulSoup(r.text, "lxml")
        org = [
            item.text.split("：")[1]
            for item in soup.find_all("div", attrs={"class": "csxm-list-comp"})
        ]
        temp_list = [
            _get_charity_china_progress_detail(
                "https://cszg.mca.gov.cn" + item["href"]
            )
            for item in soup.find_all("a")
        ]
        title = [item[0] for item in temp_list]
        num = [item[1] for item in temp_list]
        ori = [item[2] for item in temp_list]
        status = [item[3] for item in temp_list]
        inner_df = pd.DataFrame([org, title, num, ori, status]).T
        outer_df = outer_df.append(inner_df, ignore_index=True)
    outer_df.columns = ["组织", "名称", "项目编号", "发起慈善组织", "项目状态"]
    return outer_df


# 慈善中国-慈善组织年报
def _get_page_num_charity_china_report() -> int:
    """
    慈善中国-慈善组织年报-总页数
    :return: 总页数
    :rtype: int
    """
    url = "https://cszg.mca.gov.cn/biz/ma/csmh/d/csmhddoSort.html"
    payload_params = {
        "search_condit": "",
        "field": "",
        "sort": "desc",
        "flag": "0",
    }
    payload_data = {"pageNo": "1"}
    r = requests.post(url, params=payload_params, data=payload_data)
    soup = BeautifulSoup(r.text, "lxml")
    page_text = soup.find(
        "font", attrs={"style": "margin-left: 10px; color: #000000; font-weight: bold;"}
    ).text.split("/")[1]
    page_num = re.findall(re.compile(r"\d+"), page_text)[0]
    return int(page_num)


def charity_china_report() -> pd.DataFrame:
    """
    慈善中国-慈善组织年报
    https://cszg.mca.gov.cn/biz/ma/csmh/d/csmhdindex.html
    :return: 慈善中国-慈善组织年报
    :rtype: pandas.DataFrame
    """
    page_num = _get_page_num_charity_china_report()
    url = "https://cszg.mca.gov.cn/biz/ma/csmh/d/csmhddoSort.html"
    payload_params = {
        "search_condit": "",
        "field": "",
        "sort": "desc",
        "flag": "0",
    }
    outer_df = pd.DataFrame()
    for page in tqdm(range(1, page_num+1), desc="Please wait for a moment"):
        payload_data = {"pageNo": str(page)}
        r = requests.post(url, params=payload_params, data=payload_data)
        inner_df = pd.read_html(r.text)[0]
        inner_soup = BeautifulSoup(r.text, "lxml")
        inner_df["操作"] = [
            "https://cszg.mca.gov.cn/mz/upload/pub/load/resource_download.html?"
            + item["onclick"].strip("Download('").strip("')")
            for item in inner_soup.find_all("a", attrs={"style": "color: #0088DB;"})
        ]
        outer_df = outer_df.append(inner_df, ignore_index=True)
    return outer_df


# 慈善中国-募捐信息平台
def charity_china_platform() -> pd.DataFrame:
    """
    慈善中国-募捐信息平台
    https://cszg.mca.gov.cn/biz/ma/csmh/h/csmhhindex.html
    :return: 募捐信息平台
    :rtype: pandas.DataFrame
    """
    url = "https://cszg.mca.gov.cn/biz/ma/csmh/h/csmhhindex.html"
    r = requests.get(url)
    soup = BeautifulSoup(r.text, "lxml")
    info_url = [item["href"] for item in soup.find_all("a", attrs={"target": "_blank"})]
    info_org = [
        item.text for item in soup.find_all("div", attrs={"class": "fk_text_1"})
    ]
    info_title = [
        item.text for item in soup.find_all("div", attrs={"class": "fk_text_2"})
    ]
    info_contact = [
        item.text for item in soup.find_all("div", attrs={"class": "fk_text_3"})
    ]
    info_df = pd.DataFrame([info_url, info_org, info_title, info_contact]).T
    info_df.columns = ["网址", "组织", "名称", "联系方式"]
    return info_df


if __name__ == "__main__":
    # 慈善中国-慈善组织查询
    charity_organization_df = charity_china_organization()
    print(charity_organization_df)

    # 慈善中国-慈善信托查询
    charity_china_trust_df = charity_china_trust()
    print(charity_china_trust_df)

    # 慈善中国-募捐方案备案
    charity_china_plan_df = charity_china_plan()
    print(charity_china_plan_df)

    # 慈善中国-慈善项目进展
    charity_china_progress_df = charity_china_progress()
    print(charity_china_progress_df)

    # 慈善中国-慈善组织年报
    charity_china_report_df = charity_china_report()
    print(charity_china_report_df)

    # 慈善中国-募捐信息平台
    charity_china_platform_df = charity_china_platform()
    print(charity_china_platform_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2020/9/10 18:02
Desc: 东方财富网-数据中心-特色数据-商誉
东方财富网-数据中心-特色数据-商誉-A股商誉市场概况: http://data.eastmoney.com/sy/scgk.html
东方财富网-数据中心-特色数据-商誉-商誉减值预期明细: http://data.eastmoney.com/sy/yqlist.html
东方财富网-数据中心-特色数据-商誉-个股商誉减值明细: http://data.eastmoney.com/sy/jzlist.html
东方财富网-数据中心-特色数据-商誉-个股商誉明细: http://data.eastmoney.com/sy/list.html
东方财富网-数据中心-特色数据-商誉-行业商誉: http://data.eastmoney.com/sy/hylist.html
"""
from mssdk.utils import demjson
from py_mini_racer import py_mini_racer
import pandas as pd
import requests
from tqdm import tqdm

from mssdk.stock_feature.cons import stock_em_sy_js

ctx = py_mini_racer.MiniRacer()
ctx.eval(stock_em_sy_js)

# pd.set_option('display.max_columns', 500)
# pd.set_option('display.max_rows', 500)


def stock_em_sy_profile() -> pd.DataFrame:
    """
    东方财富网-数据中心-特色数据-商誉-A股商誉市场概况
    http://data.eastmoney.com/sy/scgk.html
    :return: pandas.DataFrame
    """
    url = "http://datacenter.eastmoney.com/api/data/get"
    params = {
        "type": "RPT_GOODWILL_MARKETSTATISTICS",
        "sty": "ALL",
        "p": "1",
        "ps": "50",
        "st": "REPORT_DATE",
        "sr": "-1",
        "var": "feJIrwLX",
        "filter": '(TRADE_BOARD="all")((GOODWILL_STATE="1")(|IMPAIRMENT_STATE="1"))',
        "rt": "53324344",
    }
    res = requests.get(url, params=params)
    res.encoding = "gb2312"
    data_text = res.text
    data_json = demjson.decode(
        data_text[data_text.find("{"):-1]
    )
    data_df = pd.DataFrame(data_json["result"]["data"])
    data_df.columns = [
        "_",
        "报告期",
        "商誉",
        "商誉减值",
        "净资产",
        "商誉占净资产比例",
        "商誉减值占净资产比例",
        "净利润规模",
        "商誉减值占净利润比例",
        "_",
        "_",
    ]
    data_df = data_df[
        [
            "报告期",
            "商誉",
            "商誉减值",
            "净资产",
            "商誉占净资产比例",
            "商誉减值占净资产比例",
            "净利润规模",
            "商誉减值占净利润比例",
        ]
    ]
    data_df["报告期"] = pd.to_datetime(data_df["报告期"])
    return data_df


def _get_page_num_sy_yq_list(symbol: str = "沪深两市", trade_date: str = "2019-12-31") -> int:
    """
    东方财富网-数据中心-特色数据-商誉-商誉减值预期明细
    http://data.eastmoney.com/sy/yqlist.html
    :return: int 获取 商誉减值预期明细 的总页数
    """
    symbol_dict = {
        "沪市主板": f"(MKT='shzb' and ENDDATE=^{trade_date}^)",
        "深市主板": f"(MKT='szzb' and ENDDATE=^{trade_date}^)",
        "中小板": f"(MKT='zxb' and ENDDATE=^{trade_date}^)",
        "创业板": f"(MKT='cyb' and ENDDATE=^{trade_date}^)",
        "沪深两市": f"(ENDDATE=^{trade_date}^)",
    }
    url = "http://dcfm.eastmoney.com/EM_MutiSvcExpandInterface/api/js/get"
    params = {
        "type": "SY_YG",
        "token": "894050c76af8597a853f5b408b759f5d",
        "st": "NOTICEDATE",
        "sr": "-1",
        "p": "1",
        "ps": "50",
        "js": "var {name}=".format(name=ctx.call("getCode", 8))
        + "{pages:(tp),data:(x),font:(font)}",
        "filter": symbol_dict[symbol],
        "rt": "52589731",
    }
    res = requests.get(url, params=params)
    data_json = demjson.decode(res.text[res.text.find("={") + 1 :])
    return data_json["pages"]


def stock_em_sy_yq_list(symbol: str = "沪市主板", trade_date: str = "2019-12-31") -> pd.DataFrame:
    """
    东方财富网-数据中心-特色数据-商誉-商誉减值预期明细
    http://data.eastmoney.com/sy/yqlist.html
    :return: pandas.DataFrame
    """
    symbol_dict = {
        "沪市主板": f"(MKT='shzb' and ENDDATE=^{trade_date}^)",
        "深市主板": f"(MKT='szzb' and ENDDATE=^{trade_date}^)",
        "中小板": f"(MKT='zxb' and ENDDATE=^{trade_date}^)",
        "创业板": f"(MKT='cyb' and ENDDATE=^{trade_date}^)",
        "沪深两市": f"(ENDDATE=^{trade_date}^)",
    }
    url = "http://dcfm.eastmoney.com/EM_MutiSvcExpandInterface/api/js/get"
    page_num = _get_page_num_sy_yq_list(symbol=symbol, trade_date=trade_date)
    temp_df = pd.DataFrame()
    for page in tqdm(range(1, page_num + 1)):
        params = {
            "type": "SY_YG",
            "token": "894050c76af8597a853f5b408b759f5d",
            "st": "NOTICEDATE",
            "sr": "-1",
            "p": str(page),
            "ps": "50",
            "js": "var {name}=".format(name=ctx.call("getCode", 8))
            + "{pages:(tp),data:(x),font:(font)}",
            "filter": symbol_dict[symbol],
            "rt": "52589731",
        }
        res = requests.get(url, params=params)
        data_text = res.text
        data_json = demjson.decode(data_text[data_text.find("={") + 1:])
        temp_df = temp_df.append(pd.DataFrame(data_json["data"]), ignore_index=True)
    temp_df.columns = [
        "股票代码",
        "COMPANYCODE",
        "公司名称",
        "MKT",
        "最新一期商誉(元)",
        "公告日期",
        "REPORTDATE",
        "ENDDATE",
        "PARENTNETPROFIT",
        "预计净利润(元)-下限",
        "预计净利润(元)-上限",
        "业绩变动幅度-上限",
        "业绩变动幅度-下限",
        "预告内容",
        "业绩变动原因",
        "FORECASTTYPE",
        "上年度同期净利润(元)",
        "FORECASTINDEXCODE",
        "PERIOD",
        "HYName",
        "HYCode",
        "上年商誉",
        "商誉报告日期",
    ]
    temp_df = temp_df[
        [
            "股票代码",
            "公司名称",
            "最新一期商誉(元)",
            "公告日期",
            "预计净利润(元)-下限",
            "预计净利润(元)-上限",
            "业绩变动幅度-上限",
            "业绩变动幅度-下限",
            "预告内容",
            "业绩变动原因",
            "上年度同期净利润(元)",
            "上年商誉",
            "商誉报告日期",
        ]
    ]
    temp_df["公告日期"] = pd.to_datetime(temp_df["公告日期"])
    return temp_df


def _get_page_num_sy_jz_list(symbol: str = "沪市主板", trade_date: str = "2019-06-30") -> int:
    """
    东方财富网-数据中心-特色数据-商誉-个股商誉减值明细
    http://data.eastmoney.com/sy/jzlist.html
    :return: int 获取 个股商誉减值明细 的总页数
    """
    symbol_dict = {
        "沪市主板": f"(MKT='shzb' and REPORTDATE=^{trade_date}^)",
        "深市主板": f"(MKT='szzb' and REPORTDATE=^{trade_date}^)",
        "中小板": f"(MKT='zxb' and REPORTDATE=^{trade_date}^)",
        "创业板": f"(MKT='cyb' and REPORTDATE=^{trade_date}^)",
        "沪深两市": f"(REPORTDATE=^{trade_date}^)",
    }
    url = "http://dcfm.eastmoney.com/EM_MutiSvcExpandInterface/api/js/get"
    params = {
        "type": "SY_MX",
        "token": "894050c76af8597a853f5b408b759f5d",
        "st": "GOODWILL_Change",
        "sr": "-1",
        "p": "2",
        "ps": "50",
        "js": "var {name}=".format(name=ctx.call("getCode", 8))
        + "{pages:(tp),data:(x),font:(font)}",
        "filter": symbol_dict[symbol],
        "rt": "52584576",
    }
    res = requests.get(url, params=params)
    data_json = demjson.decode(res.text[res.text.find("={") + 1 :])
    return data_json["pages"]


def stock_em_sy_jz_list(symbol: str = "沪市主板", trade_date: str = "2019-06-30") -> pd.DataFrame:
    """
    东方财富网-数据中心-特色数据-商誉-个股商誉减值明细
    http://data.eastmoney.com/sy/jzlist.html
    :return: pandas.DataFrame
    """
    symbol_dict = {
        "沪市主板": f"(MKT='shzb' and REPORTDATE=^{trade_date}^)",
        "深市主板": f"(MKT='szzb' and REPORTDATE=^{trade_date}^)",
        "中小板": f"(MKT='zxb' and REPORTDATE=^{trade_date}^)",
        "创业板": f"(MKT='cyb' and REPORTDATE=^{trade_date}^)",
        "沪深两市": f"(REPORTDATE=^{trade_date}^)",
    }
    url = "http://dcfm.eastmoney.com/EM_MutiSvcExpandInterface/api/js/get"
    page_num = _get_page_num_sy_jz_list(symbol=symbol, trade_date=trade_date)
    temp_df = pd.DataFrame()
    for page in tqdm(range(1, page_num + 1)):
        params = {
            "type": "SY_MX",
            "token": "894050c76af8597a853f5b408b759f5d",
            "st": "GOODWILL_Change",
            "sr": "-1",
            "p": str(page),
            "ps": "50",
            "js": "var {name}=".format(name=ctx.call("getCode", 8))
            + "{pages:(tp),data:(x),font:(font)}",
            "filter": symbol_dict[symbol],
            "rt": "52584576",
        }
        res = requests.get(url, params=params)
        data_text = res.text
        data_json = demjson.decode(data_text[data_text.find("={") + 1 :])
        temp_df = temp_df.append(pd.DataFrame(data_json["data"]), ignore_index=True)
    temp_df.columns = [
        "股票代码",
        "COMPANYCODE",
        "股票简称",
        "MKT",
        "REPORTTIMETYPECODE",
        "COMBINETYPECODE",
        "DATAAJUSTTYPE",
        "商誉(元)",
        "商誉减值(元)",
        "SUMSHEQUITY",
        "SUMSHEQUITY_Rate",
        "商誉减值占净资产比例(%)",
        "NOTICEDATE",
        "REPORTDATE",
        "净利润(元)",
        "商誉减值占净利润比例(%)",
        "HYName",
        "HYCode",
        "SJLTZ",
        "GOODWILL_BeforeYear",
        "公告日期",
        "ListingState",
        "MX_Type",
    ]
    temp_df = temp_df[
        [
            "股票代码",
            "股票简称",
            "商誉(元)",
            "商誉减值(元)",
            "商誉减值占净资产比例(%)",
            "净利润(元)",
            "商誉减值占净利润比例(%)",
            "公告日期",
        ]
    ]
    temp_df["公告日期"] = pd.to_datetime(temp_df["公告日期"])
    return temp_df


def _get_page_num_sy_list(symbol: str = "沪市主板", trade_date: str = "2019-12-31") -> int:
    """
    东方财富网-数据中心-特色数据-商誉-个股商誉明细
    http://data.eastmoney.com/sy/list.html
    :param symbol: choice of {"沪市主板", "深市主板", "中小板", "创业板", "沪深两市"}
    :type symbol: str
    :param trade_date: 参考网站指定的数据日期
    :type trade_date: str
    :return: 个股商誉明细 的总页数
    :rtype: int
    """
    symbol_dict = {
        "沪市主板": f"""(TRADE_BOARD="shzb")(REPORT_DATE='{trade_date}')""",
        "深市主板": f"""(TRADE_BOARD="szzb")(REPORT_DATE='{trade_date}')""",
        "中小板": f"""(TRADE_BOARD="zxb")(REPORT_DATE='{trade_date}')""",
        "创业板": f"""(TRADE_BOARD="cyb")(REPORT_DATE='{trade_date}')""",
        "沪深两市": f"(REPORT_DATE='{trade_date}')",
    }
    url = "http://datacenter.eastmoney.com/api/data/get"
    params = {
        "type": "RPT_GOODWILL_STOCKDETAILS",
        "sty": "ALL",
        "p": "1",
        "ps": "50",
        "sr": "-1,-1",
        "st": "NOTICE_DATE,SECURITY_CODE",
        "var": "QvxsKBaH",
        "filter": symbol_dict[symbol],
        "rt": "53324381",
    }
    res = requests.get(url, params=params)
    data_json = demjson.decode(res.text[res.text.find("{"):-1])
    return data_json["result"]["pages"]


def stock_em_sy_list(symbol: str = "深市主板", trade_date: str = "2019-12-31") -> pd.DataFrame:
    """
    东方财富网-数据中心-特色数据-商誉-个股商誉明细
    http://data.eastmoney.com/sy/list.html
    :param symbol: choice of {"沪市主板", "深市主板", "中小板", "创业板", "沪深两市"}
    :type symbol: str
    :param trade_date: 参考网站指定的数据日期
    :type trade_date: str
    :return: 个股商誉明细数据
    :rtype: pandas.DataFrame
    """
    symbol_dict = {
        "沪市主板": f"""(TRADE_BOARD="shzb")(REPORT_DATE='{trade_date}')""",
        "深市主板": f"""(TRADE_BOARD="szzb")(REPORT_DATE='{trade_date}')""",
        "中小板": f"""(TRADE_BOARD="zxb")(REPORT_DATE='{trade_date}')""",
        "创业板": f"""(TRADE_BOARD="cyb")(REPORT_DATE='{trade_date}')""",
        "沪深两市": f"(REPORT_DATE='{trade_date}')",
    }
    url = "http://datacenter.eastmoney.com/api/data/get"
    page_num = _get_page_num_sy_list(symbol=symbol, trade_date=trade_date)
    temp_df = pd.DataFrame()
    for page in tqdm(range(1, page_num + 1)):
        params = {
            "type": "RPT_GOODWILL_STOCKDETAILS",
            "sty": "ALL",
            "p": str(page),
            "ps": "50",
            "sr": "-1,-1",
            "st": "NOTICE_DATE,SECURITY_CODE",
            "var": "QvxsKBaH",
            "filter": symbol_dict[symbol],
            "rt": "53324381",
        }
        res = requests.get(url, params=params)
        data_text = res.text
        data_json = demjson.decode(data_text[data_text.find("{"): -1])
        temp_df = temp_df.append(pd.DataFrame(data_json["result"]["data"]), ignore_index=True)
    temp_df.columns = [
        "_",
        "股票代码",
        "股票简称",
        "_",
        "_",
        "_",
        "_",
        "商誉",
        "_",
        "_",
        "_",
        "公告日期",
        "报告期",
        "上年商誉",
        "_",
        "_",
        "商誉占净资产比例",
        "_",
        "净利率",
        "_",
        "净利润同比",
        "_",
        "_",
        "_",
        "_",
    ]
    temp_df = temp_df[
        [
            "股票代码",
            "股票简称",
            "商誉",
            "商誉占净资产比例",
            "净利率",
            "净利润同比",
            "上年商誉",
            "公告日期",
        ]
    ]
    temp_df["公告日期"] = pd.to_datetime(temp_df["公告日期"])
    temp_df["股票代码"] = temp_df["股票代码"].str.zfill(6)
    return temp_df


def _get_page_num_sy_hy_list(trade_date: str = "2019-09-30") -> int:
    """
    东方财富网-数据中心-特色数据-商誉-行业商誉
    http://data.eastmoney.com/sy/hylist.html
    :return: int 获取 行业商誉 的总页数
    """
    url = "http://dcfm.eastmoney.com/EM_MutiSvcExpandInterface/api/js/get"
    params = {
        "type": "HY_SY_SUM",
        "token": "894050c76af8597a853f5b408b759f5d",
        "st": "SUMSHEQUITY_Rate",
        "sr": "-1",
        "p": "1",
        "ps": "50",
        "js": "var {name}=".format(name=ctx.call("getCode", 8))
        + "{pages:(tp),data:(x),font:(font)}",
        "filter": f"(MKT='all' and REPORTDATE=^{trade_date}^)",
        "rt": "52584617",
    }
    res = requests.get(url, params=params)
    data_json = demjson.decode(res.text[res.text.find("={") + 1 :])
    return data_json["pages"]


def stock_em_sy_hy_list(trade_date: str = "2019-09-30") -> pd.DataFrame:
    """
    东方财富网-数据中心-特色数据-商誉-行业商誉
    http://data.eastmoney.com/sy/hylist.html
    :return: pandas.DataFrame
    """
    url = "http://dcfm.eastmoney.com/EM_MutiSvcExpandInterface/api/js/get"
    page_num = _get_page_num_sy_hy_list(trade_date=trade_date)
    temp_df = pd.DataFrame()
    for page in tqdm(range(1, page_num + 1)):
        params = {
            "type": "HY_SY_SUM",
            "token": "894050c76af8597a853f5b408b759f5d",
            "st": "SUMSHEQUITY_Rate",
            "sr": "-1",
            "p": str(page),
            "ps": "50",
            "js": "var {name}=".format(name=ctx.call("getCode", 8))
            + "{pages:(tp),data:(x),font:(font)}",
            "filter": f"(MKT='all' and REPORTDATE=^{trade_date}^)",
            "rt": "52584617",
        }
        res = requests.get(url, params=params)
        data_text = res.text
        data_json = demjson.decode(data_text[data_text.find("={") + 1 :])
        temp_df = temp_df.append(pd.DataFrame(data_json["data"]), ignore_index=True)
    temp_df.columns = [
        "行业名称",
        "HYCode",
        "MKT",
        "公司家数",
        "商誉规模(元)",
        "GOODWILL_Change",
        "净资产(元)",
        "商誉规模占净资产规模比例(%)",
        "SUMSHEQUITY_Change_Rate",
        "REPORTDATE",
        "净利润规模(元)",
        "PARENTNETPROFIT_Change_Rate",
        "SygmType",
        "SyztType",
    ]
    temp_df = temp_df[
        ["行业名称", "公司家数", "商誉规模(元)", "净资产(元)", "商誉规模占净资产规模比例(%)", "净利润规模(元)"]
    ]
    return temp_df


if __name__ == "__main__":
    stock_em_sy_profile_df = stock_em_sy_profile()
    print(stock_em_sy_profile_df)
    stock_em_sy_yq_list_df = stock_em_sy_yq_list(symbol="沪市主板", trade_date="2019-12-31")
    print(stock_em_sy_yq_list_df)
    stock_em_sy_jz_list_df = stock_em_sy_jz_list(symbol="沪市主板", trade_date="2019-12-31")
    print(stock_em_sy_jz_list_df)
    stock_em_sy_list_df = stock_em_sy_list(symbol="沪深两市", trade_date="2019-12-31")
    print(stock_em_sy_list_df)
    stock_em_sy_hy_list_df = stock_em_sy_hy_list(trade_date="2019-12-31")
    print(stock_em_sy_hy_list_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2020/4/2 20:24
Desc: 东方财富-数据中心-中国油价
http://data.eastmoney.com/cjsj/oil_default.html
"""
import json

import pandas as pd
import requests


def energy_oil_hist() -> pd.DataFrame:
    """
    汽柴油历史调价信息
    http://data.eastmoney.com/cjsj/oil_default.html
    :return: 汽柴油历史调价数
    :rtype: pandas.DataFrame
    """
    url = "http://datacenter.eastmoney.com/api/data/get"
    params = {
        "type": "RPTA_WEB_YJ_BD",
        "sty": "ALL",
        "source": "WEB",
        "p": "1",
        "ps": "5000",
        "st": "dim_date",
        "sr": "-1",
        "var": "OxGINxug",
        "rt": "52861006",
    }
    r = requests.get(url, params=params)
    data_text = r.text
    data_json = json.loads(data_text[data_text.find("{"): -1])
    temp_df = pd.DataFrame(data_json["result"]["data"])
    temp_df.columns = ["日期", "汽油价格", "柴油价格", "汽油涨幅", "柴油涨幅"]
    return temp_df


def energy_oil_detail(date: str = "2020-03-19") -> pd.DataFrame:
    """
    全国各地区的汽油和柴油油价
    http://data.eastmoney.com/cjsj/oil_default.html
    :param date: call function: energy_oil_hist to get the date point
    :type date: str
    :return: oil price at specific date
    :rtype: pandas.DataFrame
    """
    url = "http://datacenter.eastmoney.com/api/data/get"
    params = {
        "type": "RPTA_WEB_YJ_JH",
        "sty": "ALL",
        "source": "WEB",
        "p": "1",
        "ps": "5000",
        "st": "cityname",
        "sr": "1",
        "filter": f'(dim_date="{date}")',
        "var": "todayPriceData",
    }
    r = requests.get(url, params=params)
    data_text = r.text
    data_json = json.loads(data_text[data_text.find("{"): -1])
    temp_df = pd.DataFrame(data_json["result"]["data"]).iloc[:, 1:]
    return temp_df


if __name__ == "__main__":
    energy_oil_hist_df = energy_oil_hist()
    print(energy_oil_hist_df)

    energy_oil_detail_df = energy_oil_detail(date="2021-04-01")
    print(energy_oil_detail_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2021/4/19 16:56
Desc: 同花顺-数据中心-营业部排名
http://data.10jqka.com.cn/market/longhu/
"""
import requests
import pandas as pd
from tqdm import tqdm


def stock_lh_yyb_most() -> pd.DataFrame:
    """
    同花顺-数据中心-营业部排名-上榜次数最多
    http://data.10jqka.com.cn/market/longhu/
    :return: 上榜次数最多
    :rtype: pandas.DataFrame
    """
    big_df = pd.DataFrame()
    for page in tqdm(range(1, 11)):
        headers = {
            'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/89.0.4389.90 Safari/537.36'
        }
        url = f'http://data.10jqka.com.cn/ifmarket/lhbyyb/type/1/tab/sbcs/field/sbcs/sort/desc/page/{page}/'
        r = requests.get(url, headers=headers)
        temp_df = pd.read_html(r.text)[0]
        big_df = big_df.append(temp_df)
    big_df.reset_index(inplace=True, drop=True)
    return big_df


def stock_lh_yyb_capital() -> pd.DataFrame:
    """
    同花顺-数据中心-营业部排名-资金实力最强
    http://data.10jqka.com.cn/market/longhu/
    :return: 资金实力最强
    :rtype: pandas.DataFrame
    """
    big_df = pd.DataFrame()
    for page in tqdm(range(1, 11)):
        headers = {
            'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/89.0.4389.90 Safari/537.36'
        }
        url = f'http://data.10jqka.com.cn/ifmarket/lhbyyb/type/1/tab/zjsl/field/zgczje/sort/desc/page/{page}/'
        r = requests.get(url, headers=headers)
        temp_df = pd.read_html(r.text)[0]
        big_df = big_df.append(temp_df)
    big_df.reset_index(inplace=True, drop=True)
    return big_df


def stock_lh_yyb_control() -> pd.DataFrame:
    """
    同花顺-数据中心-营业部排名-抱团操作实力
    http://data.10jqka.com.cn/market/longhu/
    :return: 抱团操作实力
    :rtype: pandas.DataFrame
    """
    big_df = pd.DataFrame()
    for page in tqdm(range(1, 11)):
        headers = {
            'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/89.0.4389.90 Safari/537.36'
        }
        url = f'http://data.10jqka.com.cn/ifmarket/lhbyyb/type/1/tab/btcz/field/xsjs/sort/desc/page/{page}/'
        r = requests.get(url, headers=headers)
        temp_df = pd.read_html(r.text)[0]
        big_df = big_df.append(temp_df)
    big_df.reset_index(inplace=True, drop=True)
    return big_df


if __name__ == '__main__':
    stock_lh_yyb_most_df = stock_lh_yyb_most()
    print(stock_lh_yyb_most_df)

    stock_lh_yyb_capital_df = stock_lh_yyb_capital()
    print(stock_lh_yyb_capital_df)

    stock_lh_yyb_control_df = stock_lh_yyb_control()
    print(stock_lh_yyb_control_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2021/6/3 16:30
Desc: get currency data from website
P.S. you should get the api key from the website, you can register a gmail account to verify your email account
https://currencyscoop.com/
"""
import pandas as pd
import requests


def currency_latest(base: str = "USD", api_key: str = "") -> pd.DataFrame:
    """
    Latest data from currencyscoop.com
    https://currencyscoop.com/api-documentation
    :param base: The base currency you would like to use for your rates
    :type base: str
    :param api_key: Account -> Account Details -> API KEY (use as password in external tools)
    :type api_key: str
    :return: Latest data of base currency
    :rtype: pandas.DataFrame
    """
    payload = {"base": base, "api_key": api_key}
    url = "https://api.currencyscoop.com/v1/latest"
    r = requests.get(url, params=payload)
    temp_df = pd.DataFrame.from_dict(r.json()["response"])
    temp_df["date"] = pd.to_datetime(temp_df["date"])
    return temp_df


def currency_history(
    base: str = "USD", date: str = "2020-02-03", api_key: str = ""
) -> pd.DataFrame:
    """
    Latest data from currencyscoop.com
    https://currencyscoop.com/api-documentation
    :param base: The base currency you would like to use for your rates
    :type base: str
    :param date: Specific date, e.g., "2020-02-03"
    :type date: str
    :param api_key: Account -> Account Details -> API KEY (use as password in external tools)
    :type api_key: str
    :return: Latest data of base currency
    :rtype: pandas.DataFrame
    """
    payload = {"base": base, "date": date, "api_key": api_key}
    url = "https://api.currencyscoop.com/v1/historical"
    r = requests.get(url, params=payload)
    temp_df = pd.DataFrame.from_dict(r.json()["response"])
    temp_df["date"] = pd.to_datetime(temp_df["date"])
    return temp_df


def currency_time_series(
    base: str = "USD",
    start_date: str = "2020-02-03",
    end_date: str = "2020-03-04",
    api_key: str = "",
) -> pd.DataFrame:
    """
    Time-series data from currencyscoop.com
    P.S. need special authority
    https://currencyscoop.com/api-documentation
    :param base: The base currency you would like to use for your rates
    :type base: str
    :param start_date: Specific date, e.g., "2020-02-03"
    :type start_date: str
    :param end_date: Specific date, e.g., "2020-02-03"
    :type end_date: str
    :param api_key: Account -> Account Details -> API KEY (use as password in external tools)
    :type api_key: str
    :return: Latest data of base currency
    :rtype: pandas.DataFrame
    """
    payload = {
        "base": base,
        "api_key": api_key,
        "start_date": start_date,
        "end_date": end_date,
    }
    url = "https://api.currencyscoop.com/v1/timeseries"
    r = requests.get(url, params=payload)
    temp_df = pd.DataFrame.from_dict(r.json()["response"])
    temp_df["date"] = pd.to_datetime(temp_df["date"])
    return temp_df


def currency_currencies(c_type: str = "fiat", api_key: str = "") -> pd.DataFrame:
    """
    currencies data from currencyscoop.com
    https://currencyscoop.com/api-documentation
    :param c_type: now only "fiat" can return data
    :type c_type: str
    :param api_key: Account -> Account Details -> API KEY (use as password in external tools)
    :type api_key: str
    :return: Latest data of base currency
    :rtype: pandas.DataFrame
    """
    payload = {"type": c_type, "api_key": api_key}
    url = "https://api.currencyscoop.com/v1/currencies"
    r = requests.get(url, params=payload)
    temp_df = pd.DataFrame.from_dict(r.json()["response"]["fiats"]).T
    return temp_df


def currency_convert(
    base: str = "USD", to: str = "CNY", amount: str = "10000", api_key: str = ""
) -> pd.Series:
    """
    currencies data from currencyscoop.com
    https://currencyscoop.com/api-documentation
    :param base: The base currency you would like to use for your rates
    :type base: str
    :param to: The currency you would like to use for your rates
    :type to: str
    :param amount: The amount of base currency
    :type amount: str
    :param api_key: Account -> Account Details -> API KEY (use as password in external tools)
    :type api_key: str
    :return: Latest data of base currency
    :rtype: pandas.Series
    """
    payload = {
        "from": base,
        "to": to,
        "amount": amount,
        "api_key": api_key,
    }
    url = "https://api.currencyscoop.com/v1/convert"
    r = requests.get(url, params=payload)
    temp_se = pd.Series(r.json()["response"])
    temp_se["timestamp"] = pd.to_datetime(temp_se["timestamp"], unit="s")
    return temp_se


if __name__ == "__main__":
    currency_latest_df = currency_latest(
        base="USD", api_key=""
    )
    print(currency_latest_df)
    currency_history_df = currency_history(
        base="USD", date="2020-02-03", api_key=""
    )
    print(currency_history_df)
    # currency_time_series_df = currency_time_series(
    #     base="USD",
    #     start_date="2020-02-03",
    #     end_date="2020-03-04",
    #     api_key="",
    # )
    # print(currency_time_series_df)
    currency_currencies_df = currency_currencies(
        c_type="fiat", api_key=""
    )
    print(currency_currencies_df)
    currency_convert_se = currency_convert(
        base="USD", to="CNY", amount="10000", api_key=""
    )
    print(currency_convert_se)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2021/10/22 14:07
Desc: COVID-19
COVID-19-网易
COVID-19-丁香园
COVID-19-百度
COVID-19-GitHub
"""
import json
import time

from mssdk.utils import demjson
import jsonpath
import pandas as pd
import requests
from bs4 import BeautifulSoup

from mssdk.event.cons import province_dict, city_dict


def covid_19_163(indicator: str = "实时") -> pd.DataFrame:
    """
    网易-新型冠状病毒
    https://news.163.com/special/epidemic/?spssid=93326430940df93a37229666dfbc4b96&spsw=4&spss=other&#map_block
    https://news.163.com/special/epidemic/?spssid=93326430940df93a37229666dfbc4b96&spsw=4&spss=other&
    :return: 返回指定 indicator 的数据
    :rtype: pandas.DataFrame
    """
    url = "https://c.m.163.com/ug/api/wuhan/app/data/list-total"
    headers = {
        "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/79.0.3945.130 Safari/537.36",
    }
    payload = {
        "t": int(time.time() * 1000),
    }
    r = requests.get(url, params=payload, headers=headers)
    data_json = r.json()
    # data info
    url = "https://news.163.com/special/epidemic/"
    r = requests.get(url, headers=headers)
    soup = BeautifulSoup(r.text, "lxml")
    data_info_df = pd.DataFrame(
        [
            item.text.strip().split(".")[1]
            for item in soup.find("div", attrs={"class": "data_tip_pop_text"}).find_all(
                "p"
            )
        ]
    )
    data_info_df.columns = ["info"]

    # 中国历史时点数据
    hist_today_df = pd.DataFrame(
        [item["today"] for item in data_json["data"]["chinaDayList"]],
        index=[item["date"] for item in data_json["data"]["chinaDayList"]],
    )

    # 中国历史累计数据
    hist_total_df = pd.DataFrame(
        [item["total"] for item in data_json["data"]["chinaDayList"]],
        index=[item["date"] for item in data_json["data"]["chinaDayList"]],
    )

    # 中国实时数据
    current_df = pd.DataFrame.from_dict(data_json["data"]["chinaTotal"])

    # 世界历史时点数据
    outside_today_df = pd.DataFrame(
        [item["today"] for item in data_json["data"]["areaTree"]],
        index=[item["name"] for item in data_json["data"]["areaTree"]],
    )

    # 世界历史累计数据
    outside_total_df = pd.DataFrame(
        [item["total"] for item in data_json["data"]["areaTree"]],
        index=[item["name"] for item in data_json["data"]["areaTree"]],
    )

    # 全球所有国家及地区时点数据
    all_world_today_df = pd.DataFrame(
        jsonpath.jsonpath(data_json["data"]["areaTree"], "$..today"),
        index=jsonpath.jsonpath(data_json["data"]["areaTree"], "$..name"),
    )

    # 全球所有国家及地区累计数据
    all_world_total_df = pd.DataFrame(
        jsonpath.jsonpath(data_json["data"]["areaTree"], "$..total"),
        index=jsonpath.jsonpath(data_json["data"]["areaTree"], "$..name"),
    )

    # 中国各地区累计数据
    area_total_df = pd.DataFrame(
        [item["total"] for item in data_json["data"]["areaTree"][2]["children"]],
        index=[item["name"] for item in data_json["data"]["areaTree"][2]["children"]],
    )

    # 中国各地区时点数据
    area_today_df = pd.DataFrame(
        [item["today"] for item in data_json["data"]["areaTree"][2]["children"]],
        index=[item["name"] for item in data_json["data"]["areaTree"][2]["children"]],
    )

    # 疫情学术进展
    url_article = "https://vip.open.163.com/api/cms/topic/list"
    payload_article = {
        "topicid": "00019NGQ",
        "listnum": "1000",
        "liststart": "0",
        "pointstart": "0",
        "pointend": "255",
        "useproperty": "true",
    }
    r_article = requests.get(url_article, params=payload_article)
    article_df = pd.DataFrame(r_article.json()["data"]).iloc[:, 1:]

    # 资讯
    url_info = "https://ent.163.com/special/00035080/virus_report_data.js"
    payload_info = {
        "_": int(time.time() * 1000),
        "callback": "callback",
    }
    r_info = requests.get(url_info, params=payload_info, headers=headers)
    data_info_text = r_info.text
    data_info_json = demjson.decode(data_info_text.strip(" callback(")[:-1])

    if indicator == "数据说明":
        print(f"数据更新时间: {data_json['data']['lastUpdateTime']}")
        return data_info_df

    if indicator == "中国实时数据":
        print(f"数据更新时间: {data_json['data']['lastUpdateTime']}")
        return current_df

    if indicator == "中国历史时点数据":
        print(f"数据更新时间: {data_json['data']['lastUpdateTime']}")
        return hist_today_df

    if indicator == "中国历史累计数据":
        print(f"数据更新时间: {data_json['data']['lastUpdateTime']}")
        return hist_total_df

    if indicator == "世界历史时点数据":
        print(f"数据更新时间: {data_json['data']['lastUpdateTime']}")
        return outside_today_df

    if indicator == "世界历史累计数据":
        print(f"数据更新时间: {data_json['data']['lastUpdateTime']}")
        return outside_total_df

    if indicator == "全球所有国家及地区时点数据":
        print(f"数据更新时间: {data_json['data']['lastUpdateTime']}")
        return all_world_today_df

    elif indicator == "全球所有国家及地区累计数据":
        print(f"数据更新时间: {data_json['data']['lastUpdateTime']}")
        return all_world_total_df

    elif indicator == "中国各地区时点数据":
        print(f"数据更新时间: {data_json['data']['lastUpdateTime']}")
        return area_today_df

    elif indicator == "中国各地区累计数据":
        print(f"数据更新时间: {data_json['data']['lastUpdateTime']}")
        return area_total_df

    elif indicator == "疫情学术进展":
        return article_df

    elif indicator == "实时资讯新闻播报":
        return pd.DataFrame(data_info_json["list"])

    elif indicator == "实时医院新闻播报":
        return pd.DataFrame(data_info_json["hospital"])

    elif indicator == "前沿知识":
        return pd.DataFrame(data_info_json["papers"])

    elif indicator == "权威发布":
        return pd.DataFrame(data_info_json["power"])

    elif indicator == "境外输入疫情趋势":
        url = "https://c.m.163.com/ug/api/wuhan/app/data/list-by-area-code"
        params = {"areaCode": "66", "t": round(int(time.time() * 1000))}
        r = requests.get(url, params=params, headers=headers)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["data"]["list"])
        today_list = [item.get("input", 0) for item in temp_df["today"]]
        total_list = [item.get("input", 0) for item in temp_df["total"]]
        result_df = pd.DataFrame([today_list, total_list]).T
        result_df.columns = ["境外输入新增确诊", "境外输入累计确诊"]
        result_df.index = pd.to_datetime(temp_df.date)
        return result_df

    elif indicator == "境外输入确诊病例来源":
        url = "https://c.m.163.com/ug/api/wuhan/app/index/input-data-list"
        params = {"t": round(int(time.time() * 1000))}
        r = requests.get(url, params=params, headers=headers)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["data"]["list"])
        del temp_df["page"]
        return temp_df


def covid_19_dxy(indicator: str = "浙江省") -> pd.DataFrame:
    """
    20200315-丁香园接口更新分为国内和国外
    https://ncov.dxy.cn/ncovh5/view/pneumonia
    丁香园-全国统计-info
    丁香园-分地区统计-data
    丁香园-全国发热门诊一览表-hospital
    丁香园-全国新闻-news
    :param indicator: ["info", "data", "hospital", "news"]
    :type indicator: str
    :return: 返回指定 indicator 的数据
    :rtype: pandas.DataFrame
    """
    url = "https://ncov.dxy.cn/ncovh5/view/pneumonia"
    r = requests.get(url)
    r.encoding = "utf-8"
    soup = BeautifulSoup(r.text, "lxml")
    # news-china
    text_data_news = str(soup.find("script", attrs={"id": "getTimelineService1"}))
    temp_json = text_data_news[
        text_data_news.find("= [{") + 2 : text_data_news.rfind("}catch")
    ]
    json_data = pd.DataFrame(json.loads(temp_json))
    chinese_news = json_data[
        [
            "id",
            "pubDate",
            "pubDateStr",
            "title",
            "summary",
            "infoSource",
            "sourceUrl",
            "provinceId",
        ]
    ]

    # data-domestic
    data_text = str(soup.find("script", attrs={"id": "getAreaStat"}))
    data_text_json = json.loads(
        data_text[data_text.find("= [{") + 2 : data_text.rfind("catch") - 1]
    )
    big_df = pd.DataFrame()
    for i, p in enumerate(jsonpath.jsonpath(data_text_json, "$..provinceName")):
        temp_df = pd.DataFrame(jsonpath.jsonpath(data_text_json, "$..cities")[i])
        temp_df["province"] = p
        big_df = big_df.append(temp_df, ignore_index=True)
    domestic_city_df = big_df

    data_df = pd.DataFrame(data_text_json).iloc[:, :7]
    data_df.columns = ["地区", "地区简称", "现存确诊", "累计确诊", "-", "治愈", "死亡"]
    domestic_province_df = data_df[["地区", "地区简称", "现存确诊", "累计确诊", "治愈", "死亡"]]
    # data-global
    data_text = str(
        soup.find("script", attrs={"id": "getListByCountryTypeService2true"})
    )
    data_text_json = json.loads(
        data_text[data_text.find("= [{") + 2 : data_text.rfind("catch") - 1]
    )
    global_df = pd.DataFrame(data_text_json)

    # info
    dxy_static = str(soup.find("script", attrs={"id": "getStatisticsService"}))
    data_json = json.loads(
        dxy_static[dxy_static.find("= {") + 2 : dxy_static.rfind("}c")]
    )
    china_statistics = pd.DataFrame(
        [
            time.strftime(
                "%Y-%m-%d %H:%M:%S", time.localtime(data_json["modifyTime"] / 1000)
            ),
            data_json["currentConfirmedCount"],
            data_json["confirmedCount"],
            data_json["suspectedCount"],
            data_json["curedCount"],
            data_json["deadCount"],
            data_json["seriousCount"],
        ],
        index=[
            "数据发布时间",
            "现存确诊",
            "累计确诊",
            "境外输入",
            "累计治愈",
            "累计死亡",
            "现存重症",
        ],
        columns=["info"],
    )
    foreign_statistics = pd.DataFrame.from_dict(
        data_json["foreignStatistics"], orient="index"
    )
    global_statistics = pd.DataFrame.from_dict(
        data_json["globalStatistics"], orient="index"
    )
    # hospital
    url = (
        "https://assets.dxycdn.com/gitrepo/tod-assets/output/default/pneumonia/index.js"
    )
    payload = {"t": str(int(time.time()))}
    r = requests.get(url, params=payload)
    hospital_df = pd.read_html(r.text)[0].iloc[:, :-1]

    if indicator == "中国疫情分省统计详情":
        return domestic_province_df
    if indicator == "中国疫情分市统计详情":
        return domestic_city_df
    elif indicator == "全球疫情分国家统计详情":
        return global_df
    elif indicator == "中国疫情实时统计":
        return china_statistics
    elif indicator == "国外疫情实时统计":
        return foreign_statistics
    elif indicator == "全球疫情实时统计":
        return global_statistics
    elif indicator == "中国疫情防控医院":
        return hospital_df
    elif indicator == "国内新闻":
        return chinese_news
    else:
        try:
            data_text = str(soup.find("script", attrs={"id": "getAreaStat"}))
            data_text_json = json.loads(
                data_text[data_text.find("= [{") + 2 : data_text.rfind("catch") - 1]
            )
            data_df = pd.DataFrame(data_text_json)
            # indicator = "浙江省"
            sub_area = pd.DataFrame(
                data_df[data_df["provinceName"] == indicator]["cities"].values[0]
            )
            if sub_area.empty:
                return None
            if sub_area.shape[1] != 10:
                sub_area.columns = [
                    "区域",
                    "现在确诊人数",
                    "确诊人数",
                    "疑似人数",
                    "治愈人数",
                    "死亡人数",
                    "高危人数",
                    "中危人数",
                    "id",
                    "_",
                    "_",
                ]
                sub_area = sub_area[
                    [
                        "区域",
                        "现在确诊人数",
                        "确诊人数",
                        "疑似人数",
                        "治愈人数",
                        "死亡人数",
                        "高危人数",
                        "中危人数",
                    ]
                ]
            else:
                sub_area.columns = [
                    "区域",
                    "现在确诊人数",
                    "确诊人数",
                    "疑似人数",
                    "治愈人数",
                    "死亡人数",
                    "高危人数",
                    "中危人数",
                    "id",
                    "_",
                ]
                sub_area = sub_area[
                    [
                        "区域",
                        "现在确诊人数",
                        "确诊人数",
                        "疑似人数",
                        "治愈人数",
                        "死亡人数",
                        "高危人数",
                        "中危人数",
                    ]
                ]
            return sub_area
        except IndexError:
            print("请输入省/市的全称, 如: 浙江省/上海市 等")


def covid_19_baidu(indicator: str = "浙江") -> pd.DataFrame:
    """
    百度-新型冠状病毒肺炎-疫情实时大数据报告
    https://voice.baidu.com/act/newpneumonia/newpneumonia/?from=osari_pc_1
    百度迁徙
    https://qianxi.baidu.com/
    :param indicator: 看说明文档
    :type indicator: str
    :return: 指定 indicator 的数据
    :rtype: pandas.DataFrame
    """
    # domestic-city
    url = "https://voice.baidu.com/act/newpneumonia/newpneumonia/?from=osari_pc_1"
    r = requests.get(url)
    soup = BeautifulSoup(r.text, "lxml")
    temp_soup = str(soup.find(attrs={"id": "captain-config"}))
    data_json = demjson.decode(
        temp_soup[temp_soup.find("{") : temp_soup.rfind("}") + 1]
    )
    big_df = pd.DataFrame()
    for i, p in enumerate(
        jsonpath.jsonpath(data_json["component"][0]["caseList"], "$..area")
    ):
        temp_df = pd.DataFrame(
            jsonpath.jsonpath(data_json["component"][0]["caseList"], "$..subList")[i]
        )
        temp_df["province"] = p
        big_df = big_df.append(temp_df, ignore_index=True)
    domestic_city_df = big_df

    domestic_province_df = pd.DataFrame(data_json["component"][0]["caseList"]).iloc[
        :, :-2
    ]

    big_df = pd.DataFrame()
    for i, p in enumerate(
        jsonpath.jsonpath(data_json["component"][0]["caseOutsideList"], "$..area")
    ):
        temp_df = pd.DataFrame(
            jsonpath.jsonpath(
                data_json["component"][0]["caseOutsideList"], "$..subList"
            )[i]
        )
        temp_df["province"] = p
        big_df = big_df.append(temp_df, ignore_index=True)
    outside_city_df = big_df

    outside_country_df = pd.DataFrame(
        data_json["component"][0]["caseOutsideList"]
    ).iloc[:, :-1]

    big_df = pd.DataFrame()
    for i, p in enumerate(
        jsonpath.jsonpath(data_json["component"][0]["globalList"], "$..area")
    ):
        temp_df = pd.DataFrame(
            jsonpath.jsonpath(data_json["component"][0]["globalList"], "$..subList")[i]
        )
        temp_df["province"] = p
        big_df = big_df.append(temp_df, ignore_index=True)
    global_country_df = big_df

    global_continent_df = pd.DataFrame(data_json["component"][0]["globalList"])[
        ["area", "died", "crued", "confirmed", "confirmedRelative"]
    ]

    url = "https://opendata.baidu.com/data/inner"
    params = {
        "tn": "reserved_all_res_tn",
        "dspName": "iphone",
        "from_sf": "1",
        "dsp": "iphone",
        "resource_id": "28565",
        "alr": "1",
        "query": "国内新型肺炎最新动态",
    }
    r = requests.get(url, params=params)
    data_json = r.json()
    temp_df = pd.DataFrame(
        data_json["Result"][0]["items_v2"][0]["aladdin_res"]["DisplayData"]["result"][
            "items"
        ]
    )
    temp_df.rename(
        {
            "bjh_na": "_",
            "eventDescription": "新闻",
            "eventTime": "时间",
            "eventUrl": "链接",
            "homepageUrl": "_",
            "item_avatar": "_",
            "siteName": "来源",
        },
        axis=1,
        inplace=True,
    )
    temp_df.set_index(pd.to_datetime(temp_df["时间"], unit="s", utc=True), inplace=True)
    temp_df.index = (
        pd.to_datetime(temp_df["时间"], unit="s", utc=True)
        .tz_convert("Asia/Shanghai")
        .index
    )
    del temp_df["时间"]
    temp_df.reset_index(inplace=True)
    temp_df["时间"] = (
        pd.to_datetime(temp_df["时间"])
        .dt.date.astype(str)
        .str.cat(pd.to_datetime(temp_df["时间"]).dt.time.astype(str), sep=" ")
    )
    temp_df = temp_df[
        [
            "新闻",
            "时间",
            "来源",
            "链接",
        ]
    ]
    domestic_news = temp_df

    params = {
        "tn": "reserved_all_res_tn",
        "dspName": "iphone",
        "from_sf": "1",
        "dsp": "iphone",
        "resource_id": "28565",
        "alr": "1",
        "query": "国外新型肺炎最新动态",
    }
    r = requests.get(url, params=params)
    data_json = r.json()
    temp_df = pd.DataFrame(
        data_json["Result"][0]["items_v2"][0]["aladdin_res"]["DisplayData"]["result"][
            "items"
        ]
    )
    temp_df.rename(
        {
            "bjh_na": "_",
            "eventDescription": "新闻",
            "eventTime": "时间",
            "eventUrl": "链接",
            "homepageUrl": "_",
            "item_avatar": "_",
            "siteName": "来源",
        },
        axis=1,
        inplace=True,
    )
    temp_df = temp_df[
        [
            "新闻",
            "时间",
            "来源",
            "链接",
        ]
    ]
    temp_df.set_index(pd.to_datetime(temp_df["时间"], unit="s", utc=True), inplace=True)
    temp_df.index = (
        pd.to_datetime(temp_df["时间"], unit="s", utc=True)
        .tz_convert("Asia/Shanghai")
        .index
    )
    del temp_df["时间"]
    temp_df.reset_index(inplace=True)
    temp_df["时间"] = (
        pd.to_datetime(temp_df["时间"])
        .dt.date.astype(str)
        .str.cat(pd.to_datetime(temp_df["时间"]).dt.time.astype(str), sep=" ")
    )
    temp_df = temp_df[
        [
            "新闻",
            "时间",
            "来源",
            "链接",
        ]
    ]
    foreign_news = temp_df

    if indicator == "中国分省份详情":
        return domestic_province_df
    elif indicator == "中国分城市详情":
        return domestic_city_df
    elif indicator == "国外分国详情":
        return outside_country_df
    elif indicator == "国外分城市详情":
        return outside_city_df
    elif indicator == "全球分洲详情":
        return global_continent_df
    elif indicator == "全球分洲国家详情":
        return global_country_df
    elif indicator == "国内新型肺炎最新动态":
        return domestic_news
    elif indicator == "国外新型肺炎最新动态":
        return foreign_news


def migration_area_baidu(
    area: str = "乌鲁木齐市", indicator: str = "move_out", date: str = "20200201"
) -> pd.DataFrame:
    """
    百度地图慧眼-百度迁徙-XXX迁入地详情
    百度地图慧眼-百度迁徙-XXX迁出地详情
    以上展示 top100 结果，如不够 100 则展示全部
    迁入来源地比例: 从 xx 地迁入到当前区域的人数与当前区域迁入总人口的比值
    迁出目的地比例: 从当前区域迁出到 xx 的人口与从当前区域迁出总人口的比值
    https://qianxi.baidu.com/?from=shoubai#city=0
    :param area: 可以输入 省份 或者 具体城市 但是需要用全称
    :type area: str
    :param indicator: move_in 迁入 move_out 迁出
    :type indicator: str
    :param date: 查询的日期 20200101以后的时间
    :type date: str
    :return: 迁入地详情/迁出地详情的前 50 个
    :rtype: pandas.DataFrame
    """
    city_dict.update(province_dict)
    inner_dict = dict(zip(city_dict.values(), city_dict.keys()))
    if inner_dict[area] in province_dict.keys():
        dt_flag = "province"
    else:
        dt_flag = "city"
    url = "https://huiyan.baidu.com/migration/cityrank.jsonp"
    params = {
        "dt": dt_flag,
        "id": inner_dict[area],
        "type": indicator,
        "date": date,
    }
    r = requests.get(url, params=params)
    data_text = r.text[r.text.find("({") + 1 : r.text.rfind(");")]
    data_json = json.loads(data_text)
    temp_df = pd.DataFrame(data_json["data"]["list"])
    return temp_df


def migration_scale_baidu(
    area: str = "佛山市",
    indicator: str = "move_out",
    start_date: str = "20200110",
    end_date: str = "20200315",
) -> pd.DataFrame:
    """
    百度地图慧眼-百度迁徙-迁徙规模
    * 迁徙规模指数：反映迁入或迁出人口规模，城市间可横向对比
    * 城市迁徙边界采用该城市行政区划，包含该城市管辖的区、县、乡、村
    https://qianxi.baidu.com/?from=shoubai#city=0
    :param area: 可以输入 省份 或者 具体城市 但是需要用全称
    :type area: str
    :param indicator: move_in 迁入 move_out 迁出
    :type indicator: str
    :param start_date: 开始查询的日期 默认就可以
    :type start_date: str
    :param end_date: 结束查询的日期 20200101 以后的时间
    :type end_date: str
    :return: 时间序列的迁徙规模指数
    :rtype: pandas.DataFrame
    """
    city_dict.update(province_dict)
    inner_dict = dict(zip(city_dict.values(), city_dict.keys()))
    if inner_dict[area] in province_dict.keys():
        dt_flag = "province"
    else:
        dt_flag = "city"
    url = "https://huiyan.baidu.com/migration/historycurve.jsonp"
    payload = {
        "dt": dt_flag,
        "id": inner_dict[area],
        "type": indicator,
        "startDate": start_date,
        "endDate": end_date,
    }
    r = requests.get(url, params=payload)
    json_data = json.loads(r.text[r.text.find("({") + 1 : r.text.rfind(");")])
    temp_df = pd.DataFrame.from_dict(json_data["data"]["list"], orient="index")
    temp_df.index = pd.to_datetime(temp_df.index)
    temp_df.columns = ["迁徙规模指数"]
    temp_df = temp_df[start_date:end_date]
    return temp_df


def covid_19_trip() -> pd.DataFrame:
    """
    新型肺炎确诊患者-同程查询
    https://rl.inews.qq.com/h5/trip?from=newsapp&ADTAG=tgi.wx.share.message
    :return: 新型肺炎确诊患者-相同行程查询工具的所有历史数据
    :rtype: pandas.DataFrame
    """
    url = "https://r.inews.qq.com/api/travelFront"
    r = requests.get(url)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["data"]["list"])
    return temp_df


def covid_19_trace() -> pd.DataFrame:
    """
    腾讯新闻-疫情-病患轨迹
    https://news.qq.com/hdh5/hebeicomeon.htm#/?ADTAG=yqi
    :return: 病患轨迹
    :rtype: pandas.DataFrame
    """
    url = "https://r.inews.qq.com/api/trackmap/poilist"
    headers = {
        "user-agent": "Mozilla/5.0 (iPhone; CPU iPhone OS 13_2_3 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/13.0.3 Mobile/15E148 Safari/604.1"
    }
    r = requests.get(url, headers=headers)
    data_json = r.json()
    province_list = [item["fullname"] for item in data_json["result"]["list"]]
    big_df = pd.DataFrame()
    for province in province_list:
        url = "https://apis.map.qq.com/place_cloud/search/region"
        params = {
            "region": province,
            "page_size": "200",
            "table_id": "5ff7d526b34a3525c3169a0b",
            "key": "NFPBZ-D2N3P-T7FDV-VLBQ6-4DVM7-JQFCR",
            "fliter": "",
        }
        headers = {
            "Referer": "https://news.qq.com/",
            "Host": "apis.map.qq.com",
            "Origin": "https://news.qq.com",
            "user-agent": "Mozilla/5.0 (iPhone; CPU iPhone OS 13_2_3 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/13.0.3 Mobile/15E148 Safari/604.1",
        }
        r = requests.get(url, params=params, headers=headers)
        data_json = r.json()
        risk_level = [item["x"]["risk_level"] for item in data_json["result"]["data"]]
        count_time = [item["x"]["datetime"] for item in data_json["result"]["data"]]
        temp_df = pd.DataFrame(data_json["result"]["data"])
        del temp_df["location"]
        del temp_df["id"]
        del temp_df["polygon"]
        del temp_df["tel"]
        del temp_df["ud_id"]
        del temp_df["adcode"]
        del temp_df["x"]
        temp_df["update_time"] = pd.to_datetime(temp_df["update_time"], unit="s")
        temp_df["create_time"] = pd.to_datetime(temp_df["create_time"], unit="s")
        temp_df["risk_level"] = risk_level
        temp_df["count_time"] = count_time
        del temp_df["create_time"]
        big_df = big_df.append(temp_df, ignore_index=True)
    big_df.columns = [
        "地址",
        "城市",
        "区",
        "_",
        "省份",
        "标题",
        "更新时间",
        "风险等级",
        "统计时间",
    ]
    big_df = big_df[[
        "地址",
        "城市",
        "区",
        "省份",
        "标题",
        "更新时间",
        "风险等级",
        "统计时间",
    ]]
    return big_df


def covid_19_hist_city(city: str = "武汉市") -> pd.DataFrame:
    """
    该接口最好用代理速度比较快, 2019-12-01开始
    https://github.com/canghailan/Wuhan-2019-nCoV
    :param city: 具体的城市
    :type city: str
    :return: COVID-19 具体城市的数据
    :rtype: pandas.DataFrame
    """
    url = "https://raw.githubusercontent.com/canghailan/Wuhan-2019-nCoV/master/Wuhan-2019-nCoV.json"
    r = requests.get(url)
    data_json = r.json()
    data_df = pd.DataFrame(data_json)
    return data_df[data_df["city"] == city]


def covid_19_hist_province(province: str = "湖北省") -> pd.DataFrame:
    """
    该接口最好用代理速度比较快, 2019-12-01开始
    https://github.com/canghailan/Wuhan-2019-nCoV
    :param province: 具体的省份
    :type province: str
    :return: COVID-19 具体城市的数据
    :rtype: pandas.DataFrame
    """
    url = "https://raw.githubusercontent.com/canghailan/Wuhan-2019-nCoV/master/Wuhan-2019-nCoV.json"
    r = requests.get(url)
    data_json = r.json()
    data_df = pd.DataFrame(data_json)
    return data_df[data_df["province"] == province]


def covid_19_csse_daily(date: str = "2020-04-06") -> pd.DataFrame:
    """
    2019 Novel Coronavirus COVID-19 (2019-nCoV) Data Repository by Johns Hopkins CSSE, 采集 GitHub csv 文件需要 raw 地址
    https://github.com/CSSEGISandData/COVID-19
    :param date: from 2020-01-22 to today
    :type date: str
    :return: CSSE data
    :rtype: pandas.DataFrame
    """
    url = f"https://raw.githubusercontent.com/CSSEGISandData/COVID-19/master/csse_covid_19_data/csse_covid_19_daily_reports/{date.split('-')[1]}-{date.split('-')[2]}-{date.split('-')[0]}.csv"
    temp_df = pd.read_table(url, sep=",")
    return temp_df


def covid_19_csse_us_confirmed() -> pd.DataFrame:
    """
    2019 Novel Coronavirus COVID-19 (2019-nCoV) Data Repository by Johns Hopkins CSSE
    https://github.com/CSSEGISandData/COVID-19
    :return: us confirmed data
    :rtype: pandas.DataFrame
    """
    url = "https://raw.githubusercontent.com/CSSEGISandData/COVID-19/master/csse_covid_19_data/csse_covid_19_time_series/time_series_covid19_confirmed_US.csv"
    temp_df = pd.read_table(url, sep=",")
    return temp_df


def covid_19_csse_global_confirmed() -> pd.DataFrame:
    """
    2019 Novel Coronavirus COVID-19 (2019-nCoV) Data Repository by Johns Hopkins CSSE
    https://github.com/CSSEGISandData/COVID-19
    :return: global data
    :rtype: pandas.DataFrame
    """
    url = "https://raw.githubusercontent.com/CSSEGISandData/COVID-19/master/csse_covid_19_data/csse_covid_19_time_series/time_series_covid19_confirmed_global.csv"
    temp_df = pd.read_table(url, sep=",")
    return temp_df


def covid_19_csse_us_death() -> pd.DataFrame:
    """
    2019 Novel Coronavirus COVID-19 (2019-nCoV) Data Repository by Johns Hopkins CSSE
    https://github.com/CSSEGISandData/COVID-19
    :return: us death data
    :rtype: pandas.DataFrame
    """
    url = "https://raw.githubusercontent.com/CSSEGISandData/COVID-19/master/csse_covid_19_data/csse_covid_19_time_series/time_series_covid19_deaths_US.csv"
    temp_df = pd.read_table(url, sep=",")
    return temp_df


def covid_19_csse_global_death() -> pd.DataFrame:
    """
    2019 Novel Coronavirus COVID-19 (2019-nCoV) Data Repository by Johns Hopkins CSSE
    https://github.com/CSSEGISandData/COVID-19
    :return: global death data
    :rtype: pandas.DataFrame
    """
    url = "https://raw.githubusercontent.com/CSSEGISandData/COVID-19/master/csse_covid_19_data/csse_covid_19_time_series/time_series_covid19_deaths_global.csv"
    temp_df = pd.read_table(url, sep=",")
    return temp_df


def covid_19_csse_global_recovered() -> pd.DataFrame:
    """
    2019 Novel Coronavirus COVID-19 (2019-nCoV) Data Repository by Johns Hopkins CSSE
    https://github.com/CSSEGISandData/COVID-19
    :return: recovered data
    :rtype: pandas.DataFrame
    """
    url = "https://raw.githubusercontent.com/CSSEGISandData/COVID-19/master/csse_covid_19_data/csse_covid_19_time_series/time_series_covid19_recovered_global.csv"
    temp_df = pd.read_table(url, sep=",")
    return temp_df


if __name__ == "__main__":
    # 163
    indicator_list = [
        "数据说明",
        "中国实时数据",
        "中国历史时点数据",
        "中国历史累计数据",
        "世界历史时点数据",
        "世界历史累计数据",
        "全球所有国家及地区时点数据",
        "全球所有国家及地区累计数据",
        "中国各地区时点数据",
        "中国各地区累计数据",
        "疫情学术进展",
        "实时资讯新闻播报",
        "实时医院新闻播报",
        "前沿知识",
        "权威发布",
        "境外输入疫情趋势",
        "境外输入确诊病例来源",
    ]
    for item in indicator_list:
        print(item)
        covip_19_163_df = covid_19_163(indicator=item)
        print(covip_19_163_df)

    # dxy
    indicator_list = [
        "中国疫情分省统计详情",
        "中国疫情分市统计详情",
        "全球疫情分国家统计详情",
        "中国疫情实时统计",
        "国外疫情实时统计",
        "全球疫情实时统计",
        "中国疫情防控医院",
        "国内新闻",
        "浙江省",
    ]
    for item in indicator_list:
        # item = "国外新闻"
        print(item)
        covid_19_dxy_df = covid_19_dxy(indicator=item)
        print(covid_19_dxy_df)

    # baidu
    indicator_list = [
        "中国分省份详情",
        "中国分城市详情",
        "国外分国详情",
        "国外分城市详情",
        "全球分洲详情",
        "全球分洲国家详情",
        "国内新型肺炎最新动态",
        "国外新型肺炎最新动态",
    ]
    for item in indicator_list:
        print(item)
        covid_19_baidu_df = covid_19_baidu(indicator=item)
        print(covid_19_baidu_df)

    # 迁徙地图
    migration_area_baidu_df = migration_area_baidu(
        area="上海市", indicator="move_in", date="20201112"
    )
    print(migration_area_baidu_df)

    migration_scale_baidu_df = migration_scale_baidu(
        area="上海市", indicator="move_in", start_date="20200110", end_date="20200315"
    )
    print(migration_scale_baidu_df)

    # 同程查询
    epidemic_trip_df = covid_19_trip()
    print(epidemic_trip_df)

    # 病患轨迹
    covid_19_trace_df = covid_19_trace()
    print(covid_19_trace_df)

    # 历史数据
    epidemic_hist_city_df = covid_19_hist_city(city="武汉市")
    print(epidemic_hist_city_df)

    epidemic_hist_province_df = covid_19_hist_province(province="湖北省")
    print(epidemic_hist_province_df)

    # CSSE
    covid_19_csse_daily_df = covid_19_csse_daily(date="2020-04-13")
    print(covid_19_csse_daily_df)

    covid_19_csse_us_confirmed_df = covid_19_csse_us_confirmed()
    print(covid_19_csse_us_confirmed_df)

    covid_19_csse_global_confirmed_df = covid_19_csse_global_confirmed()
    print(covid_19_csse_global_confirmed_df)

    covid_19_csse_us_death_df = covid_19_csse_us_death()
    print(covid_19_csse_us_death_df)

    covid_19_csse_global_death_df = covid_19_csse_global_death()
    print(covid_19_csse_global_death_df)

    covid_19_csse_global_recovered_df = covid_19_csse_global_recovered()
    print(covid_19_csse_global_recovered_df)
